@@ -13,11 +13,9 @@
 # Common base resource for EC2 and S3 Authentication
 
 import datetime
-import sys
 
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
 from werkzeug import exceptions
 
 from keystone.common import provider_api
@@ -33,6 +31,7 @@ CRED_TYPE_EC2 = 'ec2'
 
 
 class ResourceBase(ks_flask.ResourceBase):
+    @ks_flask.unenforced_api
     def get(self):
         # SPECIAL CASE: GET is not allowed, raise METHOD_NOT_ALLOWED
         raise exceptions.MethodNotAllowed(valid_methods=['POST'])
@@ -133,10 +132,7 @@ class ResourceBase(ks_flask.ResourceBase):
             PROVIDERS.resource_api.assert_project_enabled(
                 project_id=project_ref['id'], project=project_ref)
         except AssertionError as e:
-            six.reraise(
-                ks_exceptions.Unauthorized,
-                ks_exceptions.Unauthorized(e),
-                sys.exc_info()[2])
+            raise ks_exceptions.Unauthorized from e
 
         self._check_timestamp(credentials)
 
