@@ -12,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import itertools
 import os.path
 
 from oslo_log import log
@@ -62,12 +61,7 @@ class Catalog(base.CatalogDriverBase):
 
       catalog.$REGION.$SERVICE.$key = $value
 
-    and is stored in a similar looking hierarchy. Where a value can contain
-    values to be interpolated by standard python string interpolation that look
-    like (the % is replaced by a $ due to paste attempting to interpolate on
-    its own:
-
-      http://localhost:$(public_port)s/
+    and is stored in a similar looking hierarchy.
 
     When expanding the template it will pass in a dict made up of the conf
     instance plus a few additional key-values, notably project_id and user_id.
@@ -89,6 +83,8 @@ class Catalog(base.CatalogDriverBase):
 
     def __init__(self, templates=None):
         super(Catalog, self).__init__()
+        LOG.warning('The templated catalog driver has been deprecated and '
+                    'will be removed in a future release.')
         if templates:
             self.templates = templates
         else:
@@ -208,8 +204,7 @@ class Catalog(base.CatalogDriverBase):
                   empty dict.
 
         """
-        substitutions = dict(
-            itertools.chain(CONF.items(), CONF.eventlet_server.items()))
+        substitutions = dict(CONF.items())
         substitutions.update({'user_id': user_id})
         silent_keyerror_failures = []
         if project_id:
@@ -241,6 +236,53 @@ class Catalog(base.CatalogDriverBase):
 
         return catalog
 
+    def get_v3_catalog(self, user_id, project_id):
+        """Retrieve and format the current V3 service catalog.
+
+        This implementation builds the V3 catalog from the V2 catalog.
+
+        :param user_id: The id of the user who has been authenticated for
+            creating service catalog.
+        :param project_id: The id of the project. 'project_id' will be None in
+            the case this being called to create a catalog to go in a domain
+            scoped token. In this case, any endpoint that requires a project_id
+            as part of their URL will be skipped.
+
+        :returns: A list representing the service catalog or an empty list
+
+        """
+        v2_catalog = self.get_catalog(user_id, project_id)
+        v3_catalog = {}
+
+        for region_name, region in v2_catalog.items():
+            for service_type, service in region.items():
+                if service_type not in v3_catalog:
+                    v3_catalog[service_type] = {
+                        'type': service_type,
+                        'endpoints': []
+                    }
+
+                for attr, value in service.items():
+                    # Attributes that end in URL are interfaces. In the V2
+                    # catalog, these are internalURL, publicURL, and adminURL.
+                    # For example, <region_name>.publicURL=<URL> in the V2
+                    # catalog becomes the V3 interface for the service:
+                    # { 'interface': 'public', 'url': '<URL>', 'region':
+                    #   'region: '<region_name>' }
+                    if attr.endswith('URL'):
+                        v3_interface = attr[:-len('URL')]
+                        v3_catalog[service_type]['endpoints'].append({
+                            'interface': v3_interface,
+                            'region': region_name,
+                            'url': value,
+                        })
+                        continue
+
+                    # Other attributes are copied to the service.
+                    v3_catalog[service_type][attr] = value
+
+        return list(v3_catalog.values())
+
     def add_endpoint_to_project(self, endpoint_id, project_id):
         raise exception.NotImplemented()
 
@@ -280,7 +322,7 @@ class Catalog(base.CatalogDriverBase):
     def get_endpoint_group_in_project(self, endpoint_group_id, project_id):
         raise exception.NotImplemented()
 
-    def list_endpoint_groups(self):
+    def list_endpoint_groups(self, hints):
         raise exception.NotImplemented()
 
     def list_endpoint_groups_for_project(self, project_id):
