@@ -42,9 +42,15 @@ class Bootstrapper(object):
         self.member_role_id = None
         self.member_role_name = 'member'
 
+        self.manager_role_id = None
+        self.manager_role_name = 'manager'
+
         self.admin_role_id = None
         self.admin_role_name = None
 
+        self.service_role_id = None
+        self.service_role_name = 'service'
+
         self.region_id = None
 
         self.service_name = None
@@ -65,7 +71,9 @@ class Bootstrapper(object):
         self._bootstrap_admin_user()
         self._bootstrap_reader_role()
         self._bootstrap_member_role()
+        self._bootstrap_manager_role()
         self._bootstrap_admin_role()
+        self._bootstrap_service_role()
         self._bootstrap_project_role_assignment()
         self._bootstrap_system_role_assignment()
         self._bootstrap_region()
@@ -122,12 +130,10 @@ class Bootstrapper(object):
             LOG.info('Created role %s', role_name)
             if not self.immutable_roles:
                 LOG.warning("Role %(role)s was created as a mutable role. It "
-                            "is recommended to make this role immutable, "
-                            "which will become the default behavior of the "
-                            "bootstrap command in the future.You can opt into "
-                            "this behavior by using the --immutable-role "
-                            "flag, or update role %(role)s with the "
-                            "'immutable' resource option.", {'role': role_name})
+                            "is recommended to make this role immutable by "
+                            "adding the 'immutable' resource option to this "
+                            "role, or re-running this command without "
+                            "--no-immutable-role.", {'role': role_name})
             return role
         except exception.Conflict:
             LOG.info('Role %s exists, skipping creation.', role_name)
@@ -162,6 +168,10 @@ class Bootstrapper(object):
                 implied_role_id
             )
 
+    def _bootstrap_service_role(self):
+        role = self._ensure_role_exists(self.service_role_name)
+        self.service_role_id = role['id']
+
     def _bootstrap_reader_role(self):
         role = self._ensure_role_exists(self.reader_role_name)
         self.reader_role_id = role['id']
@@ -171,10 +181,23 @@ class Bootstrapper(object):
         self.member_role_id = role['id']
         self._ensure_implied_role(self.member_role_id, self.reader_role_id)
 
+    def _bootstrap_manager_role(self):
+        role = self._ensure_role_exists(self.manager_role_name)
+        self.manager_role_id = role['id']
+        self._ensure_implied_role(self.manager_role_id, self.member_role_id)
+
     def _bootstrap_admin_role(self):
         role = self._ensure_role_exists(self.admin_role_name)
         self.admin_role_id = role['id']
-        self._ensure_implied_role(self.admin_role_id, self.member_role_id)
+        self._ensure_implied_role(self.admin_role_id, self.manager_role_id)
+        # NOTE(dmendiza): deployments older than 2023.2 did not have a
+        # "manager" role, so we need to clean up the old admin -> member
+        # implied role
+        try:
+            PROVIDERS.role_api.delete_implied_role(self.admin_role_id,
+                                                   self.member_role_id)
+        except exception.ImpliedRoleNotFound:
+            pass
 
     def _bootstrap_admin_user(self):
         # NOTE(morganfainberg): Do not create the user if it already exists.
