@@ -41,6 +41,11 @@ from keystone.federation import utils as mapping_engine
 from keystone.i18n import _
 from keystone.server import backends
 
+# We need to define the log level to INFO. Otherwise, when using the
+# system, we will not be able to see anything.
+log.set_defaults(default_log_levels="INFO")
+
+
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
@@ -419,47 +424,6 @@ class DbVersion(BaseApp):
         print(upgrades.get_db_version())
 
 
-class ResetLastActive(BaseApp):
-    """Reset null values for all users to current time."""
-
-    name = "reset_last_active"
-
-    @classmethod
-    def add_argument_parser(cls, subparsers):
-        parser = super().add_argument_parser(subparsers)
-        parser.add_argument(
-            '--force',
-            action='store_true',
-            help='Write to the database without asking for confirmation',
-        )
-        return parser
-
-    @staticmethod
-    def main():
-        if not CONF.command.force:
-            confirm = input(
-                "Security Warning: reset_last_active  will update all users\n"
-                "in the database with a NULL value for last_active_at to be\n"
-                "last active at the current time.  This includes users that\n"
-                "have never logged in.  If your Keystone deployment is\n"
-                "configured to use disable_user_account_days_inactive, these\n"
-                "users will still be enabled and won't be disabled until the\n"
-                "configured amount of time has passed after this command is\n"
-                "run.\n"
-                "Are you sure you want to continue [y/N]? "
-            )
-            if confirm.lower() not in ('y', 'yes'):
-                raise SystemExit('reset_last_active aborted.')
-
-        LOG.debug(
-            "Resetting null values to current time %s",
-            datetime.datetime.utcnow,
-        )
-        drivers = backends.load_backends()
-        identity_api = drivers['identity_api']
-        identity_api.reset_last_active()
-
-
 class BasePermissionsSetup(BaseApp):
     """Common user/group setup for file permissions."""
 
@@ -542,7 +506,7 @@ class FernetSetup(BasePermissionsSetup):
                 os.path.abspath(CONF.fernet_receipts.key_repository)):
             cls.initialize_fernet_repository(
                 keystone_user_id, keystone_group_id, 'fernet_receipts')
-        elif(CONF.fernet_tokens.max_active_keys !=
+        elif (CONF.fernet_tokens.max_active_keys !=
                 CONF.fernet_receipts.max_active_keys):
             # WARNING(adriant): If the directories are the same,
             # 'max_active_keys' is ignored from fernet_receipts in favor of
@@ -1253,6 +1217,8 @@ class MappingEngineTester(BaseApp):
             raise SystemExit(_("Error while opening file "
                                "%(path)s: %(err)s") % {'path': path, 'err': e})
 
+        LOG.debug("Assertions loaded: [%s].", self.assertion)
+
     def normalize_assertion(self):
         def split(line, line_num):
             try:
@@ -1288,6 +1254,9 @@ class MappingEngineTester(BaseApp):
     def main(cls):
         if CONF.command.engine_debug:
             mapping_engine.LOG.logger.setLevel('DEBUG')
+            LOG.logger.setLevel('DEBUG')
+
+            LOG.debug("Debug log level enabled!")
         else:
             mapping_engine.LOG.logger.setLevel('WARN')
 
@@ -1295,7 +1264,23 @@ class MappingEngineTester(BaseApp):
 
         tester.read_rules(CONF.command.rules)
         tester.normalize_rules()
-        mapping_engine.validate_mapping_structure(tester.rules)
+
+        attribute_mapping = tester.rules.copy()
+        if CONF.command.mapping_schema_version:
+            attribute_mapping[
+                'schema_version'] = CONF.command.mapping_schema_version
+
+        if not attribute_mapping.get('schema_version'):
+            default_schema_version = '1.0'
+            LOG.warning('No schema version defined in rules [%s]. Therefore,'
+                        'we will use the default as [%s].', attribute_mapping,
+                        default_schema_version)
+            attribute_mapping[
+                'schema_version'] = default_schema_version
+
+        LOG.info("Validating Attribute mapping rules [%s].", attribute_mapping)
+        mapping_engine.validate_mapping_structure(attribute_mapping)
+        LOG.info("Attribute mapping rules are valid.")
 
         tester.read_assertion(CONF.command.input)
         tester.normalize_assertion()
@@ -1309,6 +1294,8 @@ class MappingEngineTester(BaseApp):
         rp = mapping_engine.RuleProcessor(tester.mapping_id,
                                           tester.rules['rules'])
         mapped = rp.process(tester.assertion)
+
+        LOG.info("Result of the attribute mapping processing.")
         print(jsonutils.dumps(mapped, indent=2))
 
     @classmethod
@@ -1343,6 +1330,11 @@ class MappingEngineTester(BaseApp):
                             default=False, action="store_true",
                             help=("Enable debug messages from the mapping "
                                   "engine."))
+        parser.add_argument('--mapping-schema-version', default=None,
+                            required=False,
+                            help=("The override for the schema version of "
+                                  "the rules that are loaded in the 'rules' "
+                                  "option of the test CLI."))
 
 
 class MappingPopulate(BaseApp):
@@ -1409,7 +1401,6 @@ CMDS = [
     ProjectSetup,
     ReceiptRotate,
     ReceiptSetup,
-    ResetLastActive,
     SamlIdentityProviderMetadata,
     TokenRotate,
     TokenSetup,
