@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-
+#
 # Copyright 2013 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -35,11 +34,7 @@ if os.path.exists(os.path.join(possible_topdir,
 
 # entry point.
 def main():
-    dev_conf = os.path.join(possible_topdir,
-                            'etc',
-                            'keystone.conf')
-    config_files = None
-    if os.path.exists(dev_conf):
-        config_files = [dev_conf]
-
-    cli.main(argv=sys.argv, config_files=config_files)
+    developer_config = os.path.join(possible_topdir, 'etc', 'keystone.conf')
+    if not os.path.exists(developer_config):
+        developer_config = None
+    cli.main(argv=sys.argv, developer_config_file=developer_config)
