@@ -17,6 +17,7 @@ import stat
 from cryptography import fernet
 from oslo_log import log
 
+from keystone.common import utils
 import keystone.conf
 
 
@@ -35,8 +36,8 @@ NULL_KEY = base64.urlsafe_b64encode(b'\x00' * 32)
 
 class FernetUtils(object):
 
-    def __init__(self, key_repository=None, max_active_keys=None,
-                 config_group=None):
+    def __init__(self, key_repository, max_active_keys,
+                 config_group):
         self.key_repository = key_repository
         self.max_active_keys = max_active_keys
         self.config_group = config_group
@@ -63,8 +64,8 @@ class FernetUtils(object):
         else:
             # ensure the key repository isn't world-readable
             stat_info = os.stat(self.key_repository)
-            if(stat_info.st_mode & stat.S_IROTH or
-               stat_info.st_mode & stat.S_IXOTH):
+            if (stat_info.st_mode & stat.S_IROTH or
+                    stat_info.st_mode & stat.S_IXOTH):
                 LOG.warning(
                     'key_repository is world readable: %s',
                     self.key_repository)
@@ -74,29 +75,10 @@ class FernetUtils(object):
     def create_key_directory(self, keystone_user_id=None,
                              keystone_group_id=None):
         """Attempt to create the key directory if it doesn't exist."""
-        if not os.access(self.key_repository, os.F_OK):
-            LOG.info(
-                'key_repository does not appear to exist; attempting to '
-                'create it')
-
-            try:
-                os.makedirs(self.key_repository, 0o700)
-            except OSError:
-                LOG.error(
-                    'Failed to create key_repository: either it already '
-                    'exists or you don\'t have sufficient permissions to '
-                    'create it')
-
-            if keystone_user_id and keystone_group_id:
-                os.chown(
-                    self.key_repository,
-                    keystone_user_id,
-                    keystone_group_id)
-            elif keystone_user_id or keystone_group_id:
-                LOG.warning(
-                    'Unable to change the ownership of key_repository without '
-                    'a keystone user ID and keystone group ID both being '
-                    'provided: %s', self.key_repository)
+        utils.create_directory(
+            self.key_repository, keystone_user_id=keystone_user_id,
+            keystone_group_id=keystone_group_id
+        )
 
     def _create_new_key(self, keystone_user_id, keystone_group_id):
         """Securely create a new encryption key.
@@ -167,6 +149,27 @@ class FernetUtils(object):
 
         LOG.info('Become a valid new key: %s', valid_key_file)
 
+    def _get_key_files(self, key_repo):
+        key_files = dict()
+        keys = dict()
+        for filename in os.listdir(key_repo):
+            path = os.path.join(key_repo, str(filename))
+            if os.path.isfile(path):
+                with open(path, 'r') as key_file:
+                    try:
+                        key_id = int(filename)
+                    except ValueError:  # nosec : name is not a number
+                        pass
+                    else:
+                        key = key_file.read()
+                        if len(key) == 0:
+                            LOG.warning('Ignoring empty key found in key '
+                                        'repository: %s', path)
+                            continue
+                        key_files[key_id] = path
+                        keys[key_id] = key
+        return key_files, keys
+
     def initialize_key_repository(self, keystone_user_id=None,
                                   keystone_group_id=None):
         """Create a key repository and bootstrap it with a key.
@@ -208,16 +211,7 @@ class FernetUtils(object):
 
         """
         # read the list of key files
-        key_files = dict()
-        for filename in os.listdir(self.key_repository):
-            path = os.path.join(self.key_repository, str(filename))
-            if os.path.isfile(path):
-                try:
-                    key_id = int(filename)
-                except ValueError:  # nosec : name isn't a number
-                    pass
-                else:
-                    key_files[key_id] = path
+        key_files, _ = self._get_key_files(self.key_repository)
 
         LOG.info('Starting key rotation with %(count)s key files: '
                  '%(list)s', {
@@ -277,18 +271,7 @@ class FernetUtils(object):
             return []
 
         # build a dictionary of key_number:encryption_key pairs
-        keys = dict()
-        for filename in os.listdir(self.key_repository):
-            path = os.path.join(self.key_repository, str(filename))
-            if os.path.isfile(path):
-                with open(path, 'r') as key_file:
-                    try:
-                        key_id = int(filename)
-                    except ValueError:  # nosec : filename isn't a number,
-                        # ignore this file since it's not a key.
-                        pass
-                    else:
-                        keys[key_id] = key_file.read()
+        _, keys = self._get_key_files(self.key_repository)
 
         if len(keys) != self.max_active_keys:
             # Once the number of keys matches max_active_keys, this log entry
