@@ -18,7 +18,6 @@ import time
 import types
 
 from oslo_log import log
-import six
 import stevedore
 
 from keystone.common import provider_api
@@ -27,11 +26,6 @@ from keystone.i18n import _
 
 LOG = log.getLogger(__name__)
 
-if hasattr(inspect, 'getfullargspec'):
-    getargspec = inspect.getfullargspec
-else:
-    getargspec = inspect.getargspec
-
 
 def response_truncated(f):
     """Truncate the list returned by the wrapped function.
@@ -78,7 +72,7 @@ def load_driver(namespace, driver_name, *args):
         return driver_manager.driver
     except stevedore.exception.NoMatches:
         msg = (_('Unable to find %(name)r driver in %(namespace)r.'))
-        raise ImportError(msg, {'name': driver_name, 'namespace': namespace})
+        raise ImportError(msg % {'name': driver_name, 'namespace': namespace})
 
 
 class _TraceMeta(type):
@@ -91,7 +85,7 @@ class _TraceMeta(type):
 
     @staticmethod
     def wrapper(__f, __classname):
-        __argspec = getargspec(__f)
+        __argspec = inspect.getfullargspec(__f)
         __fn_info = '%(module)s.%(classname)s.%(funcname)s' % {
             'module': inspect.getmodule(__f).__name__,
             'classname': __classname,
@@ -155,8 +149,7 @@ class _TraceMeta(type):
         return type.__new__(meta, classname, bases, final_cls_dict)
 
 
-@six.add_metaclass(_TraceMeta)
-class Manager(object):
+class Manager(object, metaclass=_TraceMeta):
     """Base class for intermediary request layer.
 
     The Manager layer exists to support additional logic that applies to all
