@@ -10,29 +10,61 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_log import versionutils
 from oslo_policy import policy
 
 from keystone.common.policies import base
 
+DEPRECATED_REASON = (
+    "The service provider API is now aware of system scope and default roles."
+)
+
+deprecated_get_sp = policy.DeprecatedRule(
+    name=base.IDENTITY % 'get_service_provider',
+    check_str=base.RULE_ADMIN_REQUIRED,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.STEIN
+)
+deprecated_list_sp = policy.DeprecatedRule(
+    name=base.IDENTITY % 'list_service_providers',
+    check_str=base.RULE_ADMIN_REQUIRED,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.STEIN
+)
+deprecated_update_sp = policy.DeprecatedRule(
+    name=base.IDENTITY % 'update_service_provider',
+    check_str=base.RULE_ADMIN_REQUIRED,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.STEIN
+)
+deprecated_create_sp = policy.DeprecatedRule(
+    name=base.IDENTITY % 'create_service_provider',
+    check_str=base.RULE_ADMIN_REQUIRED,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.STEIN
+)
+deprecated_delete_sp = policy.DeprecatedRule(
+    name=base.IDENTITY % 'delete_service_provider',
+    check_str=base.RULE_ADMIN_REQUIRED,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.STEIN
+)
+
+
 service_provider_policies = [
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'create_service_provider',
         check_str=base.RULE_ADMIN_REQUIRED,
-        # FIXME(lbragstad): Today, keystone doesn't support federation without
-        # modifying configuration files. It makes sense to require system scope
-        # for these operations until keystone supports a way to add federated
-        # identity and service providers strictly over the API. At that point,
-        # it will make sense to include `project` in the list of `scope_types`
-        # for service provider policies.
-        scope_types=['system'],
+        scope_types=['system', 'project'],
         description='Create federated service provider.',
         operations=[{'path': ('/v3/OS-FEDERATION/service_providers/'
                               '{service_provider_id}'),
-                     'method': 'PUT'}]),
+                     'method': 'PUT'}],
+        deprecated_rule=deprecated_create_sp),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'list_service_providers',
-        check_str=base.RULE_ADMIN_REQUIRED,
-        scope_types=['system'],
+        check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
+        scope_types=['system', 'project'],
         description='List federated service providers.',
         operations=[
             {
@@ -43,12 +75,13 @@ service_provider_policies = [
                 'path': '/v3/OS-FEDERATION/service_providers',
                 'method': 'HEAD'
             }
-        ]
+        ],
+        deprecated_rule=deprecated_list_sp
     ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'get_service_provider',
-        check_str=base.RULE_ADMIN_REQUIRED,
-        scope_types=['system'],
+        check_str=base.RULE_ADMIN_OR_SYSTEM_READER,
+        scope_types=['system', 'project'],
         description='Get federated service provider.',
         operations=[
             {
@@ -61,24 +94,27 @@ service_provider_policies = [
                          '{service_provider_id}'),
                 'method': 'HEAD'
             }
-        ]
+        ],
+        deprecated_rule=deprecated_get_sp
     ),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'update_service_provider',
         check_str=base.RULE_ADMIN_REQUIRED,
-        scope_types=['system'],
+        scope_types=['system', 'project'],
         description='Update federated service provider.',
         operations=[{'path': ('/v3/OS-FEDERATION/service_providers/'
                               '{service_provider_id}'),
-                     'method': 'PATCH'}]),
+                     'method': 'PATCH'}],
+        deprecated_rule=deprecated_update_sp),
     policy.DocumentedRuleDefault(
         name=base.IDENTITY % 'delete_service_provider',
         check_str=base.RULE_ADMIN_REQUIRED,
-        scope_types=['system'],
+        scope_types=['system', 'project'],
         description='Delete federated service provider.',
         operations=[{'path': ('/v3/OS-FEDERATION/service_providers/'
                               '{service_provider_id}'),
-                     'method': 'DELETE'}])
+                     'method': 'DELETE'}],
+        deprecated_rule=deprecated_delete_sp)
 ]
 
 
