@@ -44,9 +44,7 @@ CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 WHITELISTED_PROPERTIES = [
     'tenant_id', 'project_id', 'user_id',
-    'public_bind_host', 'admin_bind_host',
-    'compute_host', 'admin_port', 'public_port',
-    'public_endpoint', ]
+    'compute_host', 'public_endpoint', ]
 
 
 # NOTE(stevermar): This UUID must stay the same, forever, across
