@@ -14,7 +14,10 @@
 
 import uuid
 
+from oslo_log import log
+
 from keystone.common import cache
+from keystone.common import driver_hints
 from keystone.common import manager
 from keystone.common import provider_api
 import keystone.conf
@@ -23,6 +26,7 @@ from keystone.federation import utils
 from keystone.i18n import _
 from keystone import notifications
 
+LOG = log.getLogger(__name__)
 
 # This is a general cache region for service providers.
 MEMOIZE = cache.get_memoization_decorator(group='federation')
@@ -44,6 +48,25 @@ class Manager(manager.Manager):
 
     def __init__(self):
         super(Manager, self).__init__(CONF.federation.driver)
+        notifications.register_event_callback(
+            notifications.ACTIONS.internal, notifications.DOMAIN_DELETED,
+            self._cleanup_identity_provider
+        )
+
+    def _cleanup_identity_provider(self, service, resource_type, operation,
+                                   payload):
+        domain_id = payload['resource_info']
+        hints = driver_hints.Hints()
+        hints.add_filter('domain_id', domain_id)
+        idps = self.driver.list_idps(hints=hints)
+        for idp in idps:
+            try:
+                self.delete_idp(idp['id'])
+            except exception.IdentityProviderNotFound:
+                LOG.debug(('Identity Provider %(idpid)s not found when '
+                           'deleting domain contents for %(domainid)s, '
+                           'continuing with cleanup.'),
+                          {'idpid': idp['id'], 'domainid': domain_id})
 
     def create_idp(self, idp_id, idp):
         auto_created_domain = False
@@ -68,12 +91,14 @@ class Manager(manager.Manager):
         # NOTE(lbragstad): If an identity provider is removed from the system,
         # then we need to invalidate the token cache. Otherwise it will be
         # possible for federated tokens to be considered valid after a service
-        # provider removes a federated identity provider resource. The `idp_id`
-        # isn't actually used when invalidating the token cache but we have to
-        # pass something.
-        notifications.Audit.internal(
-            notifications.INVALIDATE_TOKEN_CACHE_DELETED_IDP, idp_id
+        # provider removes a federated identity provider resource.
+        reason = (
+            'The token cache is being invalidated because identity provider '
+            '%(idp_id)s has been deleted. Authorization for federated users '
+            'will be recalculated and enforced accordingly the next time '
+            'they authenticate or validate a token.' % {'idp_id': idp_id}
         )
+        notifications.invalidate_token_cache_notification(reason)
 
     def _cleanup_idp_domain(self, domain_id):
         domain = {'enabled': False}
@@ -139,8 +164,10 @@ class Manager(manager.Manager):
 
     def evaluate(self, idp_id, protocol_id, assertion_data):
         mapping = self.get_mapping_from_idp_and_protocol(idp_id, protocol_id)
-        rules = mapping['rules']
-        rule_processor = utils.RuleProcessor(mapping['id'], rules)
+
+        rule_processor = utils.create_attribute_mapping_rules_processor(
+            mapping)
+
         mapped_properties = rule_processor.process(assertion_data)
         return mapped_properties, mapping['id']
 
@@ -148,6 +175,12 @@ class Manager(manager.Manager):
         self._validate_mapping_exists(protocol['mapping_id'])
         return self.driver.create_protocol(idp_id, protocol_id, protocol)
 
+    def delete_protocol(self, idp_id, protocol_id):
+        hints = driver_hints.Hints()
+        hints.add_filter('protocol_id', protocol_id)
+
+        self.driver.delete_protocol(idp_id, protocol_id)
+
     def update_protocol(self, idp_id, protocol_id, protocol):
         self._validate_mapping_exists(protocol['mapping_id'])
         return self.driver.update_protocol(idp_id, protocol_id, protocol)
