@@ -13,6 +13,7 @@
 """Utilities for Federation Extension."""
 
 import ast
+import copy
 import re
 
 import flask
@@ -49,13 +50,25 @@ ROLE_PROPERTIES = {
             "name": {
                 "type": "string"
             },
-            "additionalProperties": False
+        },
+        "additionalProperties": False
+    }
+}
+
+PROJECTS_SCHEMA = {
+    "type": "array",
+    "items": {
+        "type": "object",
+        "required": ["name", "roles"],
+        "additionalProperties": False,
+        "properties": {
+            "name": {"type": "string"},
+            "roles": ROLE_PROPERTIES
         }
     }
 }
 
-
-MAPPING_SCHEMA = {
+IDP_ATTRIBUTE_MAPPING_SCHEMA_1_0 = {
     "type": "object",
     "required": ['rules'],
     "properties": {
@@ -90,18 +103,7 @@ MAPPING_SCHEMA = {
                                     },
                                     "additionalProperties": False
                                 },
-                                "projects": {
-                                    "type": "array",
-                                    "items": {
-                                        "type": "object",
-                                        "required": ["name", "roles"],
-                                        "additionalProperties": False,
-                                        "properties": {
-                                            "name": {"type": "string"},
-                                            "roles": ROLE_PROPERTIES
-                                        }
-                                    }
-                                },
+                                "projects": PROJECTS_SCHEMA,
                                 "group": {
                                     "type": "object",
                                     "oneOf": [
@@ -135,6 +137,9 @@ MAPPING_SCHEMA = {
                     }
                 }
             }
+        },
+        "schema_version": {
+            "name": {"type": "string"}
         }
     },
     "definitions": {
@@ -240,6 +245,22 @@ MAPPING_SCHEMA = {
     }
 }
 
+# `IDP_ATTRIBUTE_MAPPING_SCHEMA_2_0` adds the domain option for projects,
+# the goal is to work in a similar fashion as `user` and `groups` properties
+IDP_ATTRIBUTE_MAPPING_SCHEMA_2_0 = copy.deepcopy(
+    IDP_ATTRIBUTE_MAPPING_SCHEMA_1_0)
+
+PROJECTS_SCHEMA_2_0 = copy.deepcopy(PROJECTS_SCHEMA)
+PROJECTS_SCHEMA_2_0["items"]["properties"][
+    "domain"] = {"$ref": "#/definitions/domain"}
+
+IDP_ATTRIBUTE_MAPPING_SCHEMA_2_0['properties']['rules']['items']['properties'][
+    'local']['items']['properties']['projects'] = PROJECTS_SCHEMA_2_0
+
+
+def get_default_attribute_mapping_schema_version():
+    return CONF.federation.attribute_mapping_default_schema_version
+
 
 class DirectMaps(object):
     """An abstraction around the remote matches.
@@ -272,7 +293,14 @@ class DirectMaps(object):
 
 
 def validate_mapping_structure(ref):
-    v = jsonschema.Draft4Validator(MAPPING_SCHEMA)
+    version = ref.get(
+        'schema_version', get_default_attribute_mapping_schema_version())
+
+    LOG.debug("Validating mapping [%s] using validator from version [%s].",
+              ref, version)
+
+    v = jsonschema.Draft4Validator(
+        IDP_ATTRIBUTE_MAPPING_SCHEMAS[version]['schema'])
 
     messages = ''
     for error in sorted(v.iter_errors(ref), key=str):
@@ -562,22 +590,16 @@ class RuleProcessor(object):
         LOG.debug('mapped_properties: %s', mapped_properties)
         return mapped_properties
 
-    def _ast_literal_eval(self, value):
-        # This is a workaround for the fact that ast.literal_eval handles the
-        # case of either a string or a list of strings, but not a potential
-        # list of ints.
-
+    @staticmethod
+    def _ast_literal_eval(value):
         try:
             values = ast.literal_eval(value)
-            # NOTE(mnaser): It's possible that the group_names_list is a
-            #               numerical value which would successfully parse
-            #               and not raise an exception, so we forcefully
-            #               raise is here.
+            # We expect a list here, but literal_eval will successfully
+            # parse and return a single value. We raise ValueError if so.
             if not isinstance(values, list):
                 raise ValueError
         except (ValueError, SyntaxError):
             values = [value]
-
         return values
 
     def _normalize_groups(self, identity_value):
@@ -615,6 +637,19 @@ class RuleProcessor(object):
                            group_names_list]
         return group_dicts
 
+    def normalize_user(self, user, default_mapping_domain):
+        """Parse and validate user mapping."""
+        if user.get('type') is None:
+            user['type'] = UserType.EPHEMERAL
+        if user.get('type') not in (UserType.EPHEMERAL, UserType.LOCAL):
+            msg = _("User type %s not supported") % user.get('type')
+            raise exception.ValidationError(msg)
+
+    def extract_groups(self, groups_by_domain):
+        for groups in list(groups_by_domain.values()):
+            for group in list({g['name']: g for g in groups}.values()):
+                yield group
+
     def _transform(self, identity_values):
         """Transform local mappings, to an easier to understand format.
 
@@ -649,23 +684,6 @@ class RuleProcessor(object):
         :rtype: dict
 
         """
-        def extract_groups(groups_by_domain):
-            for groups in list(groups_by_domain.values()):
-                for group in list({g['name']: g for g in groups}.values()):
-                    yield group
-
-        def normalize_user(user):
-            """Parse and validate user mapping."""
-            user_type = user.get('type')
-
-            if user_type and user_type not in (UserType.EPHEMERAL,
-                                               UserType.LOCAL):
-                msg = _("User type %s not supported") % user_type
-                raise exception.ValidationError(msg)
-
-            if user_type is None:
-                user['type'] = UserType.EPHEMERAL
-
         # initialize the group_ids as a set to eliminate duplicates
         user = {}
         group_ids = set()
@@ -689,18 +707,19 @@ class RuleProcessor(object):
             if 'user' in identity_value:
                 # if a mapping outputs more than one user name, log it
                 if user:
-                    LOG.warning('Ignoring user name')
+                    LOG.warning('Ignoring user [%s]',
+                                identity_value.get('user'))
                 else:
                     user = identity_value.get('user')
+
             if 'group' in identity_value:
                 group = identity_value['group']
                 if 'id' in group:
                     group_ids.add(group['id'])
                 elif 'name' in group:
-                    domain = (group['domain'].get('name') or
-                              group['domain'].get('id'))
-                    groups_by_domain.setdefault(domain, list()).append(group)
-                group_names.extend(extract_groups(groups_by_domain))
+                    groups = self.process_group_by_name(
+                        group, groups_by_domain)
+                    group_names.extend(groups)
             if 'groups' in identity_value:
                 group_dicts = self._normalize_groups(identity_value)
                 group_names.extend(group_dicts)
@@ -712,16 +731,25 @@ class RuleProcessor(object):
                 # representation of a list.
                 group_ids.update(
                     self._ast_literal_eval(identity_value['group_ids']))
-            if 'projects' in identity_value:
-                projects = identity_value['projects']
 
-        normalize_user(user)
+            if 'projects' in identity_value:
+                projects = self.extract_projects(identity_value)
+
+        self.normalize_user(user, identity_value.get('domain'))
 
         return {'user': user,
                 'group_ids': list(group_ids),
                 'group_names': group_names,
                 'projects': projects}
 
+    def process_group_by_name(self, group, groups_by_domain):
+        domain = (group['domain'].get('name') or group['domain'].get('id'))
+        groups_by_domain.setdefault(domain, list()).append(group)
+        return self.extract_groups(groups_by_domain)
+
+    def extract_projects(self, identity_value):
+        return identity_value.get('projects', [])
+
     def _update_local_mapping(self, local, direct_maps):
         """Replace any {0}, {1} ... values with data from the assertion.
 
@@ -950,3 +978,56 @@ def assert_enabled_service_provider_object(service_provider):
         tr_msg = _('Service Provider %(sp)s is disabled') % {'sp': sp_id}
         LOG.debug(msg)
         raise exception.Forbidden(tr_msg)
+
+
+class RuleProcessorToHonorDomainOption(RuleProcessor):
+    """Handles the default domain configured in the attribute mapping.
+
+    This rule processor is designed to handle the `domain` attribute
+    configured at the root of the attribute mapping. When this attribute is
+    configured, we should take it as the default one for the attribute
+    mapping, instead of the domain of the IdP. Moreover, we should respect
+    the override to it that can take place at the `groups`, `user`,
+    and `projects` attributes definition.
+    """
+
+    def __init__(self, mapping_id, rules):
+        super(RuleProcessorToHonorDomainOption, self).__init__(
+            mapping_id, rules)
+
+    def extract_projects(self, identity_value):
+        projects = identity_value.get("projects", [])
+        default_mapping_domain = identity_value.get("domain")
+        for project in projects:
+            if not project.get("domain"):
+                LOG.debug("Configuring the domain [%s] for project [%s].",
+                          default_mapping_domain, project)
+                project["domain"] = default_mapping_domain
+        return projects
+
+    def normalize_user(self, user, default_mapping_domain):
+        super(RuleProcessorToHonorDomainOption, self).normalize_user(
+            user, default_mapping_domain)
+        if not user.get("domain"):
+            LOG.debug("Configuring the domain [%s] for user [%s].",
+                      default_mapping_domain, user)
+            user["domain"] = default_mapping_domain
+        else:
+            LOG.debug("The user [%s] was configured with a domain. "
+                      "Therefore, we do not need to define.", user)
+
+
+IDP_ATTRIBUTE_MAPPING_SCHEMAS = {
+    "1.0": {"schema": IDP_ATTRIBUTE_MAPPING_SCHEMA_1_0,
+            "processor": RuleProcessor},
+    "2.0": {"schema": IDP_ATTRIBUTE_MAPPING_SCHEMA_2_0,
+            "processor": RuleProcessorToHonorDomainOption}
+}
+
+
+def create_attribute_mapping_rules_processor(mapping):
+    version = mapping.get(
+        'schema_version', get_default_attribute_mapping_schema_version())
+
+    return IDP_ATTRIBUTE_MAPPING_SCHEMAS[version]['processor'](
+        mapping['id'], mapping['rules'])
