@@ -500,20 +500,21 @@ class Manager(manager.Manager):
 
         driver = self._select_identity_driver(domain_id)
 
-        user_refs = self.list_users(domain_scope=domain_id)
-        group_refs = self.list_groups(domain_scope=domain_id)
-
-        for group in group_refs:
-            # Cleanup any existing groups.
-            try:
-                self.delete_group(group['id'])
-            except exception.GroupNotFound:
-                LOG.debug(('Group %(groupid)s not found when deleting domain '
-                           'contents for %(domainid)s, continuing with '
-                           'cleanup.'),
-                          {'groupid': group['id'], 'domainid': domain_id})
+        if driver.is_sql:
+            group_refs = self.list_groups(domain_scope=domain_id)
+            for group in group_refs:
+                # Cleanup any existing groups.
+                try:
+                    self.delete_group(group['id'])
+                except exception.GroupNotFound:
+                    LOG.debug(('Group %(groupid)s not found when deleting '
+                               'domain contents for %(domainid)s, continuing '
+                               'with cleanup.'),
+                              {'groupid': group['id'], 'domainid': domain_id})
 
         # And finally, delete the users themselves
+        user_refs = self.list_users(domain_scope=domain_id)
+
         for user in user_refs:
             try:
                 if not driver.is_sql:
@@ -923,6 +924,57 @@ class Manager(manager.Manager):
                 # backward compatible
                 pass
 
+    def _validate_federated_objects(self, fed_obj_list):
+        # Validate that the ipd and protocols exist
+        for fed_obj in fed_obj_list:
+            try:
+                self.federation_api.get_idp(fed_obj['idp_id'])
+            except exception.IdentityProviderNotFound:
+                msg = (_("Could not find Identity Provider: %s")
+                       % fed_obj['idp_id'])
+                raise exception.ValidationError(msg)
+            for protocol in fed_obj['protocols']:
+                try:
+                    self.federation_api.get_protocol(fed_obj['idp_id'],
+                                                     protocol['protocol_id'])
+                except exception.FederatedProtocolNotFound:
+                    msg = (_("Could not find federated protocol "
+                             "%(protocol)s for Identity Provider: %(idp)s.")
+                           % {'protocol': protocol['protocol_id'],
+                              'idp': fed_obj['idp_id']})
+                    raise exception.ValidationError(msg)
+
+    def _create_federated_objects(self, user_ref, fed_obj_list):
+        for fed_obj in fed_obj_list:
+            for protocols in fed_obj['protocols']:
+                federated_dict = {
+                    'user_id': user_ref['id'],
+                    'idp_id': fed_obj['idp_id'],
+                    'protocol_id': protocols['protocol_id'],
+                    'unique_id': protocols['unique_id'],
+                    'display_name': user_ref['name']
+                }
+                self.shadow_users_api.create_federated_object(
+                    federated_dict)
+
+    def _create_user_with_federated_objects(self, user, driver):
+        # If the user did not pass a federated object along inside the user
+        # object then we simply create the user as normal.
+        if not user.get('federated'):
+            if 'federated' in user:
+                del user['federated']
+            user = driver.create_user(user['id'], user)
+            return user
+        # Otherwise, validate the federated object and create the user.
+        else:
+            user_ref = user.copy()
+            del user['federated']
+            self._validate_federated_objects(user_ref['federated'])
+            user = driver.create_user(user['id'], user)
+            self._create_federated_objects(user_ref, user_ref['federated'])
+            user['federated'] = user_ref['federated']
+            return user
+
     @domains_configured
     @exception_translated('user')
     def create_user(self, user_ref, initiator=None):
@@ -945,7 +997,7 @@ class Manager(manager.Manager):
         # the underlying driver so that it could conform to rules set down by
         # that particular driver type.
         user['id'] = uuid.uuid4().hex
-        ref = driver.create_user(user['id'], user)
+        ref = self._create_user_with_federated_objects(user, driver)
         notifications.Audit.created(self._USER, user['id'], initiator)
         return self._set_domain_id_and_mapping(
             ref, domain_id, driver, mapping.EntityType.USER)
@@ -957,6 +1009,10 @@ class Manager(manager.Manager):
         domain_id, driver, entity_id = (
             self._get_domain_driver_and_entity_id(user_id))
         ref = driver.get_user(entity_id)
+        # Add user's federated objects
+        fed_objects = self.shadow_users_api.get_federated_objects(user_id)
+        if fed_objects:
+            ref['federated'] = fed_objects
         return self._set_domain_id_and_mapping(
             ref, domain_id, driver, mapping.EntityType.USER)
 
@@ -1069,6 +1125,32 @@ class Manager(manager.Manager):
             if new_ref['domain_id'] != orig_ref['domain_id']:
                 raise exception.ValidationError(_('Cannot change Domain ID'))
 
+    def _update_user_with_federated_objects(self, user, driver, entity_id):
+        # If the user did not pass a federated object along inside the user
+        # object then we simply update the user as normal and add the
+        # currently associated federated objects to user to be added to the
+        # dictionary.
+        if not user.get('federated'):
+            if 'federated' in user:
+                del user['federated']
+            user = driver.update_user(entity_id, user)
+            fed_objects = self.shadow_users_api.get_federated_objects(
+                user['id'])
+            if fed_objects:
+                user['federated'] = fed_objects
+            return user
+        # Otherwise, we validate, remove the previous user's federated objects,
+        # and update the user along with their updated federated objects.
+        else:
+            user_ref = user.copy()
+            self._validate_federated_objects(user_ref['federated'])
+            self.shadow_users_api.delete_federated_object(entity_id)
+            del user['federated']
+            user = driver.update_user(entity_id, user)
+            self._create_federated_objects(user, user_ref['federated'])
+            user['federated'] = user_ref['federated']
+            return user
+
     @domains_configured
     @exception_translated('user')
     def update_user(self, user_id, user_ref, initiator=None):
@@ -1097,7 +1179,7 @@ class Manager(manager.Manager):
         self.get_user_by_name.invalidate(self, old_user_ref['name'],
                                          old_user_ref['domain_id'])
 
-        ref = driver.update_user(entity_id, user)
+        ref = self._update_user_with_federated_objects(user, driver, entity_id)
 
         notifications.Audit.updated(self._USER, user_id, initiator)
 
@@ -1126,18 +1208,12 @@ class Manager(manager.Manager):
 
         hints = driver_hints.Hints()
         hints.add_filter('user_id', user_id)
-        fed_users = PROVIDERS.shadow_users_api.list_federated_users_info(hints)
 
         driver.delete_user(entity_id)
         PROVIDERS.assignment_api.delete_user_assignments(user_id)
         self.get_user.invalidate(self, user_id)
         self.get_user_by_name.invalidate(self, user_old['name'],
                                          user_old['domain_id'])
-        for fed_user in fed_users:
-            self.shadow_federated_user.invalidate(
-                self, fed_user['idp_id'], fed_user['protocol_id'],
-                fed_user['unique_id'], fed_user['display_name'],
-                user_old.get('extra', {}).get('email'))
 
         PROVIDERS.credential_api.delete_credentials_for_user(user_id)
         PROVIDERS.id_mapping_api.delete_id_mapping(user_id)
@@ -1228,6 +1304,12 @@ class Manager(manager.Manager):
             for user_id in user_ids:
                 self._persist_revocation_event_for_user(user_id)
 
+            reason_s = (
+                'Invalidating the token cache because group %(group_id)s '
+                'has been deleted.' % {'group_id': group_id}
+            )
+            notifications.invalidate_token_cache_notification(reason_s)
+
         # Invalidate user role assignments cache region, as it may be caching
         # role assignments expanded from the specified group to its users
         assignment.COMPUTED_ASSIGNMENTS_REGION.invalidate()
@@ -1280,6 +1362,16 @@ class Manager(manager.Manager):
         # Invalidate user role assignments cache region, as it may be caching
         # role assignments expanded from this group to this user
         assignment.COMPUTED_ASSIGNMENTS_REGION.invalidate()
+        reason = (
+            'Invalidating the token cache because user %(user_id)s was '
+            'removed from group %(group_id)s. Authorization will be '
+            'calculated and enforced accordingly the next time they '
+            'authenticate or validate a token.' % {
+                'user_id': user_id,
+                'group_id': group_id,
+            }
+        )
+        notifications.invalidate_token_cache_notification(reason)
         notifications.Audit.removed_from(self._GROUP, group_id, self._USER,
                                          user_id, initiator)
 
@@ -1308,6 +1400,9 @@ class Manager(manager.Manager):
             # driver selection, so remove any such filter
             self._mark_domain_id_filter_satisfied(hints)
         ref_list = driver.list_groups_for_user(entity_id, hints)
+        for ref in ref_list:
+            if 'membership_expires_at' not in ref:
+                ref['membership_expires_at'] = None
         return self._set_domain_id_and_mapping(
             ref_list, domain_id, driver, mapping.EntityType.GROUP)
 
@@ -1389,6 +1484,13 @@ class Manager(manager.Manager):
 
         notifications.Audit.updated(self._USER, user_id, initiator)
         self._persist_revocation_event_for_user(user_id)
+        reason_s = (
+            'Invalidating the token cache because user %(user_id)s changed '
+            'the password. Authorization will be calculated and enforced '
+            'accordingly the next time they authenticate or validate a '
+            'token.' % {'user_id': user_id}
+        )
+        notifications.invalidate_token_cache_notification(reason_s)
 
     @MEMOIZE
     def _shadow_nonlocal_user(self, user):
@@ -1397,45 +1499,63 @@ class Manager(manager.Manager):
         except exception.UserNotFound:
             return PROVIDERS.shadow_users_api.create_nonlocal_user(user)
 
-    @MEMOIZE
-    def shadow_federated_user(self, idp_id, protocol_id, unique_id,
-                              display_name, email=None):
-        """Map a federated user to a user.
-
-        :param idp_id: identity provider id
-        :param protocol_id: protocol id
-        :param unique_id: unique id for the user within the IdP
-        :param display_name: user's display name
-        :param email: user's email
-
-        :returns: dictionary of the mapped User entity
-        """
+    def _shadow_federated_user(self, idp_id, protocol_id, user):
         user_dict = {}
+        email = user.get('email')
         try:
+            LOG.debug("Trying to update name for federated user [%s].", user)
+
             PROVIDERS.shadow_users_api.update_federated_user_display_name(
-                idp_id, protocol_id, unique_id, display_name)
+                idp_id, protocol_id, user['id'], user['name'])
             user_dict = PROVIDERS.shadow_users_api.get_federated_user(
-                idp_id, protocol_id, unique_id)
+                idp_id, protocol_id, user['id'])
+
             if email:
+                LOG.debug("Executing the e-mail update for federated user "
+                          "[%s].", user)
+
                 user_ref = {"email": email}
                 self.update_user(user_dict['id'], user_ref)
                 user_dict.update({"email": email})
         except exception.UserNotFound:
-            idp = PROVIDERS.federation_api.get_idp(idp_id)
             federated_dict = {
                 'idp_id': idp_id,
                 'protocol_id': protocol_id,
-                'unique_id': unique_id,
-                'display_name': display_name
+                'unique_id': user['id'],
+                'display_name': user['name']
             }
+            LOG.debug("Creating federated user [%s].", user)
             user_dict = (
                 PROVIDERS.shadow_users_api.create_federated_user(
-                    idp['domain_id'], federated_dict, email=email
+                    user["domain"]['id'],
+                    federated_dict, email=email
                 )
             )
         PROVIDERS.shadow_users_api.set_last_active_at(user_dict['id'])
         return user_dict
 
+    def shadow_federated_user(self, idp_id, protocol_id, user, group_ids=None):
+        """Map a federated user to a user.
+
+        :param idp_id: identity provider id
+        :param protocol_id: protocol id
+        :param user: User dictionary
+        :param group_ids: list of group ids to add the user to
+
+        :returns: dictionary of the mapped User entity
+        """
+        user_dict = self._shadow_federated_user(idp_id, protocol_id, user)
+
+        # Note(knikolla): The shadowing operation can be cached,
+        # however we need to update the expiring group memberships.
+        if group_ids:
+            for group_id in group_ids:
+                LOG.info("Adding user [%s] to group [%s].",
+                         user_dict, group_id)
+                PROVIDERS.shadow_users_api.add_user_to_group_expires(
+                    user_dict['id'], group_id)
+        return user_dict
+
 
 class MappingManager(manager.Manager):
     """Default pivot point for the ID Mapping backend."""
