@@ -21,7 +21,7 @@ class IDMapping(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'id_mapping'
     public_id = sql.Column(sql.String(64), primary_key=True)
     domain_id = sql.Column(sql.String(64), nullable=False)
-    local_id = sql.Column(sql.String(64), nullable=False)
+    local_id = sql.Column(sql.String(255), nullable=False)
     # NOTE(henry-nash): Postgres requires a name to be defined for an Enum
     entity_type = sql.Column(
         sql.Enum(identity_mapping.EntityType.USER,
@@ -64,7 +64,7 @@ class Mapping(base.MappingDriverBase):
 
     def get_id_mapping(self, public_id):
         with sql.session_for_read() as session:
-            mapping_ref = session.query(IDMapping).get(public_id)
+            mapping_ref = session.get(IDMapping, public_id)
             if mapping_ref:
                 return mapping_ref.to_dict()
 
