@@ -16,7 +16,6 @@ from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_serialization import msgpackutils
 from oslo_utils import reflection
-import six
 
 from keystone.common import cache
 from keystone.common import provider_api
@@ -80,6 +79,9 @@ class TokenModel(object):
         self.application_credential_id = None
         self.__application_credential = None
 
+        self.oauth2_credential_id = None
+        self.oauth2_thumbprint = None
+
     def __repr__(self):
         """Return string representation of TokenModel."""
         desc = ('<%(type)s (audit_id=%(audit_id)s, '
@@ -102,7 +104,7 @@ class TokenModel(object):
 
     @expires_at.setter
     def expires_at(self, value):
-        if not isinstance(value, six.string_types):
+        if not isinstance(value, str):
             raise ValueError('expires_at must be a string.')
         self.__expires_at = value
 
@@ -112,7 +114,7 @@ class TokenModel(object):
 
     @issued_at.setter
     def issued_at(self, value):
-        if not isinstance(value, six.string_types):
+        if not isinstance(value, str):
             raise ValueError('issued_at must be a string.')
         self.__issued_at = value
 
@@ -441,6 +443,9 @@ class TokenModel(object):
 
         return roles
 
+    def _get_oauth2_credential_roles(self):
+        return self._get_project_roles()
+
     @property
     def roles(self):
         if self.system_scoped:
