@@ -29,7 +29,7 @@ from keystone.oauth1.backends import base
 random = _random.SystemRandom()
 
 
-class Consumer(sql.ModelBase, sql.DictBase):
+class Consumer(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'consumer'
     attributes = ['id', 'description', 'secret']
     id = sql.Column(sql.String(64), primary_key=True, nullable=False)
@@ -38,7 +38,7 @@ class Consumer(sql.ModelBase, sql.DictBase):
     extra = sql.Column(sql.JsonBlob(), nullable=False)
 
 
-class RequestToken(sql.ModelBase, sql.DictBase):
+class RequestToken(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'request_token'
     attributes = ['id', 'request_secret',
                   'verifier', 'authorizing_user_id', 'requested_project_id',
@@ -61,7 +61,7 @@ class RequestToken(sql.ModelBase, sql.DictBase):
         return dict(self.items())
 
 
-class AccessToken(sql.ModelBase, sql.DictBase):
+class AccessToken(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'access_token'
     attributes = ['id', 'access_secret', 'authorizing_user_id',
                   'project_id', 'role_ids', 'consumer_id',
@@ -86,7 +86,7 @@ class AccessToken(sql.ModelBase, sql.DictBase):
 
 class OAuth1(base.Oauth1DriverBase):
     def _get_consumer(self, session, consumer_id):
-        consumer_ref = session.query(Consumer).get(consumer_id)
+        consumer_ref = session.get(Consumer, consumer_id)
         if consumer_ref is None:
             raise exception.NotFound(_('Consumer not found'))
         return consumer_ref
@@ -152,7 +152,7 @@ class OAuth1(base.Oauth1DriverBase):
         request_token_id = uuid.uuid4().hex
         request_token_secret = uuid.uuid4().hex
         expiry_date = None
-        if request_token_duration:
+        if request_token_duration > 0:
             now = timeutils.utcnow()
             future = now + datetime.timedelta(seconds=request_token_duration)
             expiry_date = utils.isotime(future, subsecond=True)
@@ -172,7 +172,7 @@ class OAuth1(base.Oauth1DriverBase):
             return token_ref.to_dict()
 
     def _get_request_token(self, session, request_token_id):
-        token_ref = session.query(RequestToken).get(request_token_id)
+        token_ref = session.get(RequestToken, request_token_id)
         if token_ref is None:
             raise exception.NotFound(_('Request token not found'))
         return token_ref
@@ -207,7 +207,7 @@ class OAuth1(base.Oauth1DriverBase):
             token_dict = req_token_ref.to_dict()
 
             expiry_date = None
-            if access_token_duration:
+            if access_token_duration > 0:
                 now = timeutils.utcnow()
                 future = (now +
                           datetime.timedelta(seconds=access_token_duration))
@@ -231,7 +231,7 @@ class OAuth1(base.Oauth1DriverBase):
             return token_ref.to_dict()
 
     def _get_access_token(self, session, access_token_id):
-        token_ref = session.query(AccessToken).get(access_token_id)
+        token_ref = session.get(AccessToken, access_token_id)
         if token_ref is None:
             raise exception.NotFound(_('Access token not found'))
         return token_ref
