@@ -32,3 +32,17 @@ consumer_update = {
     'minProperties': 1,
     'additionalProperties': True
 }
+
+request_token_authorize = {
+    'type': 'array',
+    'items': {
+        'type': 'object',
+        'properties': {
+            'id': parameter_types.id_string,
+            'name': parameter_types.name,
+        },
+        'minProperties': 1,
+        'maxProperties': 1,
+        'additionalProperties': False
+    }
+}
