@@ -1,4 +1,4 @@
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,7 +17,7 @@ from keystone import exception
 from keystone.policy.backends import rules
 
 
-class PolicyModel(sql.ModelBase, sql.DictBase):
+class PolicyModel(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'policy'
     attributes = ['id', 'blob', 'type']
     id = sql.Column(sql.String(64), primary_key=True)
@@ -43,7 +43,7 @@ class Policy(rules.Policy):
 
     def _get_policy(self, session, policy_id):
         """Private method to get a policy model object (NOT a dictionary)."""
-        ref = session.query(PolicyModel).get(policy_id)
+        ref = session.get(PolicyModel, policy_id)
         if not ref:
             raise exception.PolicyNotFound(policy_id=policy_id)
         return ref
