@@ -13,7 +13,7 @@
 from keystone.common import sql
 from keystone import exception
 from keystone.i18n import _
-from keystone import resource
+from keystone.resource.config_backends import base
 
 
 class WhiteListedConfig(sql.ModelBase, sql.ModelDictMixin):
@@ -48,7 +48,7 @@ class ConfigRegister(sql.ModelBase, sql.ModelDictMixin):
     domain_id = sql.Column(sql.String(64), nullable=False)
 
 
-class DomainConfig(resource.DomainConfigDriverV8):
+class DomainConfig(base.DomainConfigDriverBase):
 
     def choose_table(self, sensitive):
         if sensitive:
@@ -56,15 +56,23 @@ class DomainConfig(resource.DomainConfigDriverV8):
         else:
             return WhiteListedConfig
 
-    @sql.handle_conflicts(conflict_type='domain_config')
-    def create_config_option(self, domain_id, group, option, value,
-                             sensitive=False):
+    def _create_config_option(
+            self, session, domain_id, group, option, sensitive, value):
+        config_table = self.choose_table(sensitive)
+        ref = config_table(domain_id=domain_id, group=group, option=option,
+                           value=value)
+        session.add(ref)
+
+    def create_config_options(self, domain_id, option_list):
         with sql.session_for_write() as session:
-            config_table = self.choose_table(sensitive)
-            ref = config_table(domain_id=domain_id, group=group,
-                               option=option, value=value)
-            session.add(ref)
-            return ref.to_dict()
+            for config_table in [WhiteListedConfig, SensitiveConfig]:
+                query = session.query(config_table)
+                query = query.filter_by(domain_id=domain_id)
+                query.delete(False)
+            for option in option_list:
+                self._create_config_option(
+                    session, domain_id, option['group'],
+                    option['option'], option['sensitive'], option['value'])
 
     def _get_config_option(self, session, domain_id, group, option, sensitive):
         try:
@@ -97,25 +105,17 @@ class DomainConfig(resource.DomainConfigDriverV8):
                     query = query.filter_by(option=option)
             return [ref.to_dict() for ref in query.all()]
 
-    def update_config_option(self, domain_id, group, option, value,
-                             sensitive=False):
+    def update_config_options(self, domain_id, option_list):
         with sql.session_for_write() as session:
-            ref = self._get_config_option(session, domain_id, group, option,
-                                          sensitive)
-            ref.value = value
-            return ref.to_dict()
+            for option in option_list:
+                self._delete_config_options(
+                    session, domain_id, option['group'], option['option'])
+                self._create_config_option(
+                    session, domain_id, option['group'], option['option'],
+                    option['sensitive'], option['value'])
 
-    def delete_config_options(self, domain_id, group=None, option=None,
-                              sensitive=False):
-        """Deletes config options that match the filter parameters.
-
-        Since the public API is broken down into calls for delete in both the
-        whitelisted and sensitive methods, we are silent at the driver level
-        if there was nothing to delete.
-
-        """
-        with sql.session_for_write() as session:
-            config_table = self.choose_table(sensitive)
+    def _delete_config_options(self, session, domain_id, group, option):
+        for config_table in [WhiteListedConfig, SensitiveConfig]:
             query = session.query(config_table)
             query = query.filter_by(domain_id=domain_id)
             if group:
@@ -124,6 +124,10 @@ class DomainConfig(resource.DomainConfigDriverV8):
                     query = query.filter_by(option=option)
             query.delete(False)
 
+    def delete_config_options(self, domain_id, group=None, option=None):
+        with sql.session_for_write() as session:
+            self._delete_config_options(session, domain_id, group, option)
+
     def obtain_registration(self, domain_id, type):
         try:
             with sql.session_for_write() as session:
@@ -137,7 +141,7 @@ class DomainConfig(resource.DomainConfigDriverV8):
 
     def read_registration(self, type):
         with sql.session_for_read() as session:
-            ref = session.query(ConfigRegister).get(type)
+            ref = session.get(ConfigRegister, type)
             if not ref:
                 raise exception.ConfigRegistrationNotFound()
             return ref.domain_id
