@@ -10,9 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import sqlalchemy
+
 from keystone.common import sql
 from keystone.models import revoke_model
-from keystone import revoke
+from keystone.revoke.backends import base
+
+from oslo_db import api as oslo_db_api
 
 
 class RevocationEvent(sql.ModelBase, sql.ModelDictMixin):
@@ -29,14 +33,22 @@ class RevocationEvent(sql.ModelBase, sql.ModelDictMixin):
     trust_id = sql.Column(sql.String(64))
     consumer_id = sql.Column(sql.String(64))
     access_token_id = sql.Column(sql.String(64))
-    issued_before = sql.Column(sql.DateTime(), nullable=False)
+    issued_before = sql.Column(sql.DateTime(), nullable=False, index=True)
     expires_at = sql.Column(sql.DateTime())
     revoked_at = sql.Column(sql.DateTime(), nullable=False, index=True)
     audit_id = sql.Column(sql.String(32))
     audit_chain_id = sql.Column(sql.String(32))
+    __table_args__ = (
+        sql.Index('ix_revocation_event_project_id_issued_before', 'project_id',
+                  'issued_before'),
+        sql.Index('ix_revocation_event_user_id_issued_before', 'user_id',
+                  'issued_before'),
+        sql.Index('ix_revocation_event_audit_id_issued_before',
+                  'audit_id', 'issued_before'),
+    )
 
 
-class Revoke(revoke.RevokeDriverV8):
+class Revoke(base.RevokeDriverBase):
     def _flush_batch_size(self, dialect):
         batch_size = 0
         if dialect == 'ibm_db_sa':
@@ -56,7 +68,7 @@ class Revoke(revoke.RevokeDriverV8):
         return batch_size
 
     def _prune_expired_events(self):
-        oldest = revoke.revoked_before_cutoff_time()
+        oldest = base.revoked_before_cutoff_time()
 
         with sql.session_for_write() as session:
             dialect = session.bind.dialect.name
@@ -78,7 +90,34 @@ class Revoke(revoke.RevokeDriverV8):
 
             session.flush()
 
-    def list_events(self, last_fetch=None):
+    def _list_token_events(self, token):
+        with sql.session_for_read() as session:
+            query = session.query(RevocationEvent).filter(
+                RevocationEvent.issued_before >= token['issued_at'])
+            user = [RevocationEvent.user_id.is_(None)]
+            proj = [RevocationEvent.project_id.is_(None)]
+            audit = [RevocationEvent.audit_id.is_(None)]
+            trust = [RevocationEvent.trust_id.is_(None)]
+            if token['user_id']:
+                user.append(RevocationEvent.user_id == token['user_id'])
+            if token['trustor_id']:
+                user.append(RevocationEvent.user_id == token['trustor_id'])
+            if token['trustee_id']:
+                user.append(RevocationEvent.user_id == token['trustee_id'])
+            if token['project_id']:
+                proj.append(RevocationEvent.project_id == token['project_id'])
+            if token['audit_id']:
+                audit.append(RevocationEvent.audit_id == token['audit_id'])
+            if token['trust_id']:
+                trust.append(RevocationEvent.trust_id == token['trust_id'])
+            query = query.filter(sqlalchemy.and_(sqlalchemy.or_(*user),
+                                                 sqlalchemy.or_(*proj),
+                                                 sqlalchemy.or_(*audit),
+                                                 sqlalchemy.or_(*trust)))
+            events = [revoke_model.RevokeEvent(**e.to_dict()) for e in query]
+            return events
+
+    def _list_last_fetch_events(self, last_fetch=None):
         with sql.session_for_read() as session:
             query = session.query(RevocationEvent).order_by(
                 RevocationEvent.revoked_at)
@@ -87,9 +126,15 @@ class Revoke(revoke.RevokeDriverV8):
                 query = query.filter(RevocationEvent.revoked_at > last_fetch)
 
             events = [revoke_model.RevokeEvent(**e.to_dict()) for e in query]
-
             return events
 
+    def list_events(self, last_fetch=None, token=None):
+        if token:
+            return self._list_token_events(token)
+        else:
+            return self._list_last_fetch_events(last_fetch)
+
+    @oslo_db_api.wrap_db_retry(retry_on_deadlock=True)
     def revoke(self, event):
         kwargs = dict()
         for attr in revoke_model.REVOKE_KEYS:
