@@ -13,7 +13,6 @@
 import abc
 import collections
 import functools
-import itertools
 import re
 import uuid
 import wsgiref.util
@@ -22,11 +21,10 @@ import flask
 from flask import blueprints
 import flask_restful
 import flask_restful.utils
+import http.client
 from oslo_log import log
 from oslo_log import versionutils
 from oslo_serialization import jsonutils
-import six
-from six.moves import http_client
 
 from keystone.common import authorization
 from keystone.common import context
@@ -156,13 +154,12 @@ def _assert_rbac_enforcement_called(resp):
 
 def _remove_content_type_on_204(resp):
     # Remove content-type if the resp is 204.
-    if resp.status_code == http_client.NO_CONTENT:
+    if resp.status_code == http.client.NO_CONTENT:
         resp.headers.pop('content-type', None)
     return resp
 
 
-@six.add_metaclass(abc.ABCMeta)
-class APIBase(object):
+class APIBase(object, metaclass=abc.ABCMeta):
 
     @property
     @abc.abstractmethod
@@ -807,7 +804,7 @@ class ResourceBase(flask_restful.Resource):
         val = False
         if filter_name in flask.request.args:
             filter_value = flask.request.args.get(filter_name)
-            if (isinstance(filter_value, six.string_types) and
+            if (isinstance(filter_value, str) and
                     filter_value == '0'):
                 val = False
             else:
@@ -1004,12 +1001,9 @@ class ResourceBase(flask_restful.Resource):
 def base_url(path=''):
     url = CONF['public_endpoint']
 
-    if url:
-        substitutions = dict(
-            itertools.chain(CONF.items(), CONF.eventlet_server.items()))
-
-        url = url % substitutions
-    elif flask.request.environ:
+    if not url:
+        if not flask.request.environ:
+            raise ValueError('Endpoint cannot be detected')
         url = wsgiref.util.application_uri(flask.request.environ)
         # remove version from the URL as it may be part of SCRIPT_NAME but
         # it should not be part of base URL
@@ -1017,11 +1011,6 @@ def base_url(path=''):
 
         # now remove the standard port
         url = utils.remove_standard_port(url)
-    else:
-        # if we don't have enough information to come up with a base URL,
-        # then fall back to localhost. This should never happen in
-        # production environment.
-        url = 'http://localhost:%d' % CONF.eventlet_server.public_port
 
     if path:
         # Cleanup leading /v3 if needed.
