@@ -12,7 +12,6 @@
 
 
 import functools
-import itertools
 import re
 import wsgiref.util
 
@@ -73,12 +72,9 @@ def best_match_language(req):
 def base_url(context):
     url = CONF['public_endpoint']
 
-    if url:
-        substitutions = dict(
-            itertools.chain(CONF.items(), CONF.eventlet_server.items()))
-
-        url = url % substitutions
-    elif 'environment' in context:
+    if not url:
+        if 'environment' not in context:
+            raise ValueError('Endpoint cannot be detected')
         url = wsgiref.util.application_uri(context['environment'])
         # remove version from the URL as it may be part of SCRIPT_NAME but
         # it should not be part of base URL
@@ -86,11 +82,6 @@ def base_url(context):
 
         # now remove the standard port
         url = utils.remove_standard_port(url)
-    else:
-        # if we don't have enough information to come up with a base URL,
-        # then fall back to localhost. This should never happen in
-        # production environment.
-        url = 'http://localhost:%d' % CONF.eventlet_server.public_port
 
     return url.rstrip('/')
 
@@ -351,9 +342,11 @@ class AuthContextMiddleware(provider_api.ProviderAPIMixin,
 
         if not context_env.get('is_admin', False):
             resp = super(AuthContextMiddleware, self).process_request(request)
-
             if resp:
                 return resp
+            if request.token_auth.has_user_token and \
+                    not request.user_token_valid:
+                raise exception.Unauthorized(_('Not authorized.'))
             if request.token_auth.user is not None:
                 request.set_user_headers(request.token_auth.user)
 
@@ -371,7 +364,7 @@ class AuthContextMiddleware(provider_api.ProviderAPIMixin,
         if token.domain_scoped:
             # Domain scoped tokens should never have is_admin_project set
             # Even if KSA defaults it otherwise.  The two mechanisms are
-            # parallel; only ione or the other should be used for access.
+            # parallel; only one or the other should be used for access.
             request_context.is_admin_project = False
             request_context.domain_id = token.domain_id
             request_context.domain_name = token.domain['name']
