@@ -21,8 +21,8 @@ from keystone.tests.unit.ksfixtures import database
 class BaseBackendSqlTests(unit.SQLDriverOverrides, unit.TestCase):
 
     def setUp(self):
-        super(BaseBackendSqlTests, self).setUp()
-        self.useFixture(database.Database())
+        super().setUp()
+        self.database_fixture = self.useFixture(database.Database())
         self.load_backends()
 
         # populate the engine with tables & fixtures
@@ -38,15 +38,16 @@ class BaseBackendSqlTests(unit.SQLDriverOverrides, unit.TestCase):
 
 class BaseBackendSqlModels(BaseBackendSqlTests):
 
-    def select_table(self, name):
-        table = sqlalchemy.Table(name,
-                                 sql.ModelBase.metadata,
-                                 autoload=True)
-        s = sqlalchemy.select([table])
-        return s
+    def load_table(self, name):
+        table = sqlalchemy.Table(
+            name,
+            sql.ModelBase.metadata,
+            autoload_with=self.database_fixture.engine,
+        )
+        return table
 
     def assertExpectedSchema(self, table, cols):
-        table = self.select_table(table)
+        table = self.load_table(table)
         for col, type_, length in cols:
             self.assertIsInstance(table.c[col].type, type_)
             if length:
