@@ -77,7 +77,7 @@ class UtilsTestCase(unit.BaseTestCase):
         self.config_fixture.config(strict_password_check=False)
         password = uuid.uuid4().hex
         verified = common_utils.verify_length_and_trunc_password(password)
-        self.assertEqual(password, verified)
+        self.assertEqual(password.encode('utf-8'), verified)
 
     def test_that_a_hash_can_not_be_validated_against_a_hash(self):
         # NOTE(dstanek): Bug 1279849 reported a problem where passwords
@@ -97,7 +97,7 @@ class UtilsTestCase(unit.BaseTestCase):
         max_length = CONF.identity.max_password_length
         invalid_password = 'passw0rd'
         trunc = common_utils.verify_length_and_trunc_password(invalid_password)
-        self.assertEqual(invalid_password[:max_length], trunc)
+        self.assertEqual(invalid_password.encode('utf-8')[:max_length], trunc)
 
     def test_verify_long_password_strict_raises_exception(self):
         self.config_fixture.config(strict_password_check=True)
@@ -139,12 +139,23 @@ class UtilsTestCase(unit.BaseTestCase):
         self.config_fixture.config(group='identity',
                                    password_hash_algorithm='bcrypt')
         self.config_fixture.config(group='identity',
-                                   max_password_length='64')
-        invalid_length_password = '0' * 64
+                                   max_password_length='96')
+        invalid_length_password = '0' * 96
         self.assertRaises(exception.PasswordVerificationError,
                           common_utils.hash_password,
                           invalid_length_password)
 
+    def test_bcrypt_sha256_not_truncate_password(self):
+        self.config_fixture.config(strict_password_check=True)
+        self.config_fixture.config(group='identity',
+                                   password_hash_algorithm='bcrypt_sha256')
+        password = '0' * 128
+        password_verified = \
+            common_utils.verify_length_and_trunc_password(password)
+        hashed = common_utils.hash_password(password)
+        self.assertTrue(common_utils.check_password(password, hashed))
+        self.assertEqual(password.encode('utf-8'), password_verified)
+
     def _create_test_user(self, password=OPTIONAL):
         user = {"name": "hthtest"}
         if password is not self.OPTIONAL:
