@@ -23,6 +23,8 @@ from keystone.federation import utils as mapping_utils
 from keystone.tests import unit
 from keystone.tests.unit import mapping_fixtures
 
+from unittest import mock
+
 
 CONF = keystone.conf.CONF
 FAKE_MAPPING_ID = uuid.uuid4().hex
@@ -262,6 +264,44 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self._rule_engine_regex_match_and_many_groups(
             mapping_fixtures.MALFORMED_TESTER_ASSERTION)
 
+    def test_rule_engine_regex_blacklist(self):
+        mapping = mapping_fixtures.MAPPING_GROUPS_BLACKLIST_REGEX
+        assertion = mapping_fixtures.EMPLOYEE_PARTTIME_ASSERTION
+        rp = mapping_utils.RuleProcessor(FAKE_MAPPING_ID, mapping['rules'])
+        mapped = rp.process(assertion)
+
+        expected = {
+            'user': {'type': 'ephemeral'},
+            'projects': [],
+            'group_ids': [],
+            'group_names': [
+                {'name': 'Manager', 'domain': {
+                    'id': mapping_fixtures.FEDERATED_DOMAIN}}
+            ]
+        }
+
+        self.assertEqual(expected, mapped)
+
+    def test_rule_engine_regex_whitelist(self):
+        mapping = mapping_fixtures.MAPPING_GROUPS_WHITELIST_REGEX
+        assertion = mapping_fixtures.EMPLOYEE_PARTTIME_ASSERTION
+        rp = mapping_utils.RuleProcessor(FAKE_MAPPING_ID, mapping['rules'])
+        mapped = rp.process(assertion)
+
+        expected = {
+            'user': {'type': 'ephemeral'},
+            'projects': [],
+            'group_ids': [],
+            'group_names': [
+                {'name': 'Employee', 'domain': {
+                    'id': mapping_fixtures.FEDERATED_DOMAIN}},
+                {'name': 'PartTimeEmployee', 'domain': {
+                    'id': mapping_fixtures.FEDERATED_DOMAIN}}
+            ]
+        }
+
+        self.assertEqual(expected, mapped)
+
     def test_rule_engine_fails_after_discarding_nonstring(self):
         """Check whether RuleProcessor discards non string objects.
 
@@ -515,10 +555,18 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertIsNotNone(mapped_properties)
         self.assertValidMappedUserObject(mapped_properties)
         self.assertEqual('jsmith', mapped_properties['user']['name'])
-        unique_id, display_name = mapped.get_user_unique_id_and_display_name(
-            mapped_properties)
-        self.assertEqual('jsmith', unique_id)
-        self.assertEqual('jsmith', display_name)
+
+        resource_api_mock = mock.patch(
+            'keystone.resource.core.DomainConfigManager')
+        idp_domain_id = uuid.uuid4().hex
+        mapped.validate_and_prepare_federated_user(mapped_properties,
+                                                   idp_domain_id,
+                                                   resource_api_mock)
+
+        self.assertEqual('jsmith', mapped_properties['user']['id'])
+        self.assertEqual('jsmith', mapped_properties['user']['name'])
+        self.assertEqual(idp_domain_id,
+                         mapped_properties['user']['domain']['id'])
 
     def test_user_identifications_name_and_federated_domain(self):
         """Test various mapping options and how users are identified.
@@ -538,10 +586,20 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         mapped_properties = rp.process(assertion)
         self.assertIsNotNone(mapped_properties)
         self.assertValidMappedUserObject(mapped_properties)
-        unique_id, display_name = mapped.get_user_unique_id_and_display_name(
-            mapped_properties)
-        self.assertEqual('tbo', display_name)
-        self.assertEqual('abc123%40example.com', unique_id)
+
+        resource_api_mock = mock.patch(
+            'keystone.resource.core.DomainConfigManager')
+        idp_domain_id = uuid.uuid4().hex
+        user_domain_id = mapped_properties['user']['domain']['id']
+        mapped.validate_and_prepare_federated_user(mapped_properties,
+                                                   idp_domain_id,
+                                                   resource_api_mock)
+
+        self.assertEqual('tbo', mapped_properties['user']['name'])
+        self.assertEqual('abc123%40example.com',
+                         mapped_properties['user']['id'])
+        self.assertEqual(user_domain_id,
+                         mapped_properties['user']['domain']['id'])
 
     def test_user_identification_id(self):
         """Test various mapping options and how users are identified.
@@ -562,10 +620,17 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertIsNotNone(mapped_properties)
         self.assertValidMappedUserObject(mapped_properties)
         with self.flask_app.test_request_context():
-            unique_id, display_name = (
-                mapped.get_user_unique_id_and_display_name(mapped_properties))
-        self.assertEqual('bob', unique_id)
-        self.assertEqual('bob', display_name)
+            resource_api_mock = mock.patch(
+                'keystone.resource.core.DomainConfigManager')
+            idp_domain_id = uuid.uuid4().hex
+            mapped.validate_and_prepare_federated_user(mapped_properties,
+                                                       idp_domain_id,
+                                                       resource_api_mock)
+
+        self.assertEqual('bob', mapped_properties['user']['name'])
+        self.assertEqual('bob', mapped_properties['user']['id'])
+        self.assertEqual(idp_domain_id,
+                         mapped_properties['user']['domain']['id'])
 
     def test_get_user_unique_id_and_display_name(self):
 
@@ -578,10 +643,17 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertValidMappedUserObject(mapped_properties)
         with self.flask_app.test_request_context(
                 environ_base={'REMOTE_USER': 'remote_user'}):
-            unique_id, display_name = (
-                mapped.get_user_unique_id_and_display_name(mapped_properties))
-        self.assertEqual('bob', unique_id)
-        self.assertEqual('remote_user', display_name)
+            resource_api_mock = mock.patch(
+                'keystone.resource.core.DomainConfigManager')
+            idp_domain_id = uuid.uuid4().hex
+            mapped.validate_and_prepare_federated_user(mapped_properties,
+                                                       idp_domain_id,
+                                                       resource_api_mock)
+
+        self.assertEqual('remote_user', mapped_properties['user']['name'])
+        self.assertEqual('bob', mapped_properties['user']['id'])
+        self.assertEqual(idp_domain_id,
+                         mapped_properties['user']['domain']['id'])
 
     def test_user_identification_id_and_name(self):
         """Test various mapping options and how users are identified.
@@ -612,11 +684,20 @@ class MappingRuleEngineTests(unit.BaseTestCase):
             mapped_properties = rp.process(assertion)
             self.assertIsNotNone(mapped_properties)
             self.assertValidMappedUserObject(mapped_properties)
-            unique_id, display_name = (
-                mapped.get_user_unique_id_and_display_name(mapped_properties)
-            )
-            self.assertEqual(exp_user_name, display_name)
-            self.assertEqual('abc123%40example.com', unique_id)
+
+            resource_api_mock = mock.patch(
+                'keystone.resource.core.DomainConfigManager')
+            idp_domain_id = uuid.uuid4().hex
+            user_domain_id = mapped_properties['user']['domain']['id']
+            mapped.validate_and_prepare_federated_user(mapped_properties,
+                                                       idp_domain_id,
+                                                       resource_api_mock)
+
+            self.assertEqual(exp_user_name, mapped_properties['user']['name'])
+            self.assertEqual('abc123%40example.com',
+                             mapped_properties['user']['id'])
+            self.assertEqual(user_domain_id,
+                             mapped_properties['user']['domain']['id'])
 
     def test_whitelist_pass_through(self):
         mapping = mapping_fixtures.MAPPING_GROUPS_WHITELIST_PASS_THROUGH
@@ -726,6 +807,24 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertEqual('ALL USERS',
                          mapped_properties['group_names'][0]['name'])
 
+    def test_rule_engine_groups_mapping_only_one_numerical_group(self):
+        """Test mapping engine when groups is explicitly set.
+
+        If the groups list has only one group,
+        test if the transformation is done correctly
+
+        """
+        mapping = mapping_fixtures.MAPPING_GROUPS_WITH_EMAIL
+        assertion = mapping_fixtures.GROUPS_ASSERTION_ONLY_ONE_NUMERICAL_GROUP
+        rp = mapping_utils.RuleProcessor(FAKE_MAPPING_ID, mapping['rules'])
+        mapped_properties = rp.process(assertion)
+        self.assertIsNotNone(mapped_properties)
+        self.assertEqual('jsmith', mapped_properties['user']['name'])
+        self.assertEqual('jill@example.com',
+                         mapped_properties['user']['email'])
+        self.assertEqual('1234',
+                         mapped_properties['group_names'][0]['name'])
+
     def test_rule_engine_group_ids_mapping_whitelist(self):
         """Test mapping engine when group_ids is explicitly set.
 
@@ -739,7 +838,7 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertIsNotNone(mapped_properties)
         self.assertEqual('opilotte', mapped_properties['user']['name'])
         self.assertListEqual([], mapped_properties['group_names'])
-        self.assertItemsEqual(['abc123', 'ghi789', 'klm012'],
+        self.assertCountEqual(['abc123', 'ghi789', 'klm012'],
                               mapped_properties['group_ids'])
 
     def test_rule_engine_group_ids_mapping_blacklist(self):
@@ -755,7 +854,7 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertIsNotNone(mapped_properties)
         self.assertEqual('opilotte', mapped_properties['user']['name'])
         self.assertListEqual([], mapped_properties['group_names'])
-        self.assertItemsEqual(['abc123', 'ghi789', 'klm012'],
+        self.assertCountEqual(['abc123', 'ghi789', 'klm012'],
                               mapped_properties['group_ids'])
 
     def test_rule_engine_group_ids_mapping_only_one_group(self):
@@ -772,7 +871,7 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         self.assertIsNotNone(mapped_properties)
         self.assertEqual('opilotte', mapped_properties['user']['name'])
         self.assertListEqual([], mapped_properties['group_names'])
-        self.assertItemsEqual(['210mlk', '321cba'],
+        self.assertCountEqual(['210mlk', '321cba'],
                               mapped_properties['group_ids'])
 
     def test_mapping_projects(self):
@@ -801,6 +900,31 @@ class MappingRuleEngineTests(unit.BaseTestCase):
         ]
         self.assertEqual(expected_projects, values['projects'])
 
+    def test_rule_engine_for_groups_and_domain(self):
+        """Should return user's groups and group domain.
+
+        The GROUP_DOMAIN_ASSERTION should successfully have a match in
+        MAPPING_GROUPS_DOMAIN_OF_USER. This will test the case where a groups
+        with its domain will exist`, and return user's groups and group domain.
+
+        """
+        mapping = mapping_fixtures.MAPPING_GROUPS_DOMAIN_OF_USER
+        assertion = mapping_fixtures.GROUPS_DOMAIN_ASSERTION
+        rp = mapping_utils.RuleProcessor(FAKE_MAPPING_ID, mapping['rules'])
+        values = rp.process(assertion)
+
+        self.assertValidMappedUserObject(values)
+        user_name = assertion.get('openstack_user')
+        user_groups = ['group1', 'group2']  # since we know the input assertion
+        groups = values.get('group_names', {})
+        group_list = [g.get('name') for g in groups]
+        group_ids = values.get('group_ids')
+        name = values.get('user', {}).get('name')
+
+        self.assertEqual(user_name, name)
+        self.assertEqual(user_groups, group_list)
+        self.assertEqual([], group_ids, )
+
 
 class TestUnicodeAssertionData(unit.BaseTestCase):
     """Ensure that unicode data in the assertion headers works.
