@@ -12,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import absolute_import
 import atexit
 import base64
 import contextlib
@@ -20,14 +19,19 @@ import datetime
 import functools
 import hashlib
 import json
+import secrets
+
 import ldap
 import os
 import shutil
 import socket
 import sys
 import uuid
-import warnings
 
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.serialization import Encoding
+from cryptography import x509
 import fixtures
 import flask
 from flask import testing as flask_testing
@@ -38,7 +42,6 @@ from oslo_context import fixture as oslo_ctx_fixture
 from oslo_log import fixture as log_fixture
 from oslo_log import log
 from oslo_utils import timeutils
-from sqlalchemy import exc
 import testtools
 from testtools import testcase
 
@@ -86,7 +89,7 @@ IN_MEM_DB_CONN_STRING = 'sqlite://'
 # Strictly matches ISO 8601 timestamps with subsecond precision like:
 # 2016-06-28T20:48:56.000000Z
 TIME_FORMAT = '%Y-%m-%dT%H:%M:%S.%fZ'
-TIME_FORMAT_REGEX = '^\d{4}-[0-1]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d{6}Z$'
+TIME_FORMAT_REGEX = r'^\d{4}-[0-1]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d{6}Z$'
 
 exception._FATAL_EXCEPTION_FORMAT_ERRORS = True
 os.makedirs(TMPDIR)
@@ -143,8 +146,8 @@ def skip_if_cache_disabled(*sections):
     arguments to only check global caching.
 
     If a specified configuration section does not define the `caching` option,
-    this decorator makes the same assumption as the `should_cache_fn` in
-    keystone.common.cache that caching should be enabled.
+    this decorator makes the caching enabled if `enabled` option in the `cache`
+    section of the configuration is true.
 
     """
     def wrapper(f):
@@ -424,9 +427,9 @@ def new_ec2_credential(user_id, project_id=None, blob=None, **kwargs):
 
 def new_totp_credential(user_id, project_id=None, blob=None):
     if not blob:
-        # NOTE(notmorgan): 20 bytes of data from os.urandom for
+        # NOTE(notmorgan): 20 bytes of data from secrets.token_bytes for
         # a totp secret.
-        blob = base64.b32encode(os.urandom(20)).decode('utf-8')
+        blob = base64.b32encode(secrets.token_bytes(20)).decode('utf-8')
     credential = new_credential_ref(user_id=user_id,
                                     project_id=project_id,
                                     blob=blob,
@@ -434,6 +437,77 @@ def new_totp_credential(user_id, project_id=None, blob=None):
     return credential
 
 
+def create_dn(
+    common_name=None,
+    locality_name=None,
+    state_or_province_name=None,
+    organization_name=None,
+    organizational_unit_name=None,
+    country_name=None,
+    street_address=None,
+    domain_component=None,
+    user_id=None,
+    email_address=None,
+):
+    oid = x509.NameOID
+    attr = x509.NameAttribute
+    dn = []
+    if common_name:
+        dn.append(attr(oid.COMMON_NAME, common_name))
+    if locality_name:
+        dn.append(attr(oid.LOCALITY_NAME, locality_name))
+    if state_or_province_name:
+        dn.append(attr(oid.STATE_OR_PROVINCE_NAME, state_or_province_name))
+    if organization_name:
+        dn.append(attr(oid.ORGANIZATION_NAME, organization_name))
+    if organizational_unit_name:
+        dn.append(attr(oid.ORGANIZATIONAL_UNIT_NAME, organizational_unit_name))
+    if country_name:
+        dn.append(attr(oid.COUNTRY_NAME, country_name))
+    if street_address:
+        dn.append(attr(oid.STREET_ADDRESS, street_address))
+    if domain_component:
+        dn.append(attr(oid.DOMAIN_COMPONENT, domain_component))
+    if user_id:
+        dn.append(attr(oid.USER_ID, user_id))
+    if email_address:
+        dn.append(attr(oid.EMAIL_ADDRESS, email_address))
+    return x509.Name(dn)
+
+
+def update_dn(dn1, dn2):
+    dn1_attrs = {attr.oid: attr for attr in dn1}
+    dn2_attrs = {attr.oid: attr for attr in dn2}
+    dn1_attrs.update(dn2_attrs)
+    return x509.Name([attr for attr in dn1_attrs.values()])
+
+
+def create_certificate(subject_dn, ca=None, ca_key=None):
+    private_key = rsa.generate_private_key(
+        public_exponent=65537,
+        key_size=2048,
+    )
+    issuer = ca.subject if ca else subject_dn
+    if not ca_key:
+        ca_key = private_key
+    today = datetime.datetime.today()
+    cert = x509.CertificateBuilder(
+        issuer_name=issuer,
+        subject_name=subject_dn,
+        public_key=private_key.public_key(),
+        serial_number=x509.random_serial_number(),
+        not_valid_before=today,
+        not_valid_after=today + datetime.timedelta(365, 0, 0),
+    ).sign(ca_key, hashes.SHA256())
+
+    return cert, private_key
+
+
+def create_pem_certificate(subject_dn, ca=None, ca_key=None):
+    cert, _ = create_certificate(subject_dn, ca=ca, ca_key=ca_key)
+    return cert.public_bytes(Encoding.PEM).decode('ascii')
+
+
 def new_application_credential_ref(roles=None,
                                    name=None,
                                    expires=None,
@@ -680,14 +754,9 @@ class BaseTestCase(testtools.TestCase):
         self.useFixture(fixtures.MockPatchObject(sys, 'exit',
                                                  side_effect=UnexpectedExit))
         self.useFixture(log_fixture.get_logging_handle_error_fixture())
+        self.stdlog = self.useFixture(ksfixtures.StandardLogging())
+        self.useFixture(ksfixtures.WarningsFixture())
 
-        warnings.filterwarnings('error', category=DeprecationWarning,
-                                module='^keystone\\.')
-        warnings.simplefilter('error', exc.SAWarning)
-        if hasattr(exc, "RemovedIn20Warning"):
-            warnings.simplefilter('ignore', exc.RemovedIn20Warning)
-
-        self.addCleanup(warnings.resetwarnings)
         # Ensure we have an empty threadlocal context at the start of each
         # test.
         self.assertIsNone(oslo_context.get_current())
@@ -1022,8 +1091,8 @@ class TestCase(BaseTestCase):
             value,
             "%s != %s" % (expected, value))
 
-    def assertNotEmpty(self, l):
-        self.assertGreater(len(l), 0)
+    def assertNotEmpty(self, iterable):
+        self.assertGreater(len(iterable), 0)
 
     def assertUserDictEqual(self, expected, observed, message=''):
         """Assert that a user dict is equal to another user dict.
