@@ -11,6 +11,7 @@
 # under the License.
 
 import datetime
+from unittest import mock
 import uuid
 
 from keystone.common import provider_api
@@ -18,6 +19,7 @@ from keystone.common import sql
 import keystone.conf
 from keystone import exception
 from keystone.identity.backends import sql_model as model
+from keystone.identity.shadow_backends import sql as shadow_sql
 from keystone.tests import unit
 
 
@@ -66,7 +68,7 @@ class ShadowUsersBackendTests(object):
         user_created = PROVIDERS.shadow_users_api.create_nonlocal_user(user)
         self.assertEqual(user_created['id'], user['id'])
         user_found = PROVIDERS.shadow_users_api.get_user(user_created['id'])
-        self.assertItemsEqual(user_created, user_found)
+        self.assertCountEqual(user_created, user_found)
 
     def test_create_federated_user_unique_constraint(self):
         user_dict = PROVIDERS.shadow_users_api.create_federated_user(
@@ -83,6 +85,11 @@ class ShadowUsersBackendTests(object):
             self.domain_id, self.federated_user)
         self.assertEqual(user['domain_id'], self.domain_id)
 
+    def test_create_federated_user_email(self):
+        user = PROVIDERS.shadow_users_api.create_federated_user(
+            self.domain_id, self.federated_user, self.email)
+        self.assertEqual(user['email'], self.email)
+
     def test_get_federated_user(self):
         user_dict_create = PROVIDERS.shadow_users_api.create_federated_user(
             self.domain_id, self.federated_user)
@@ -90,7 +97,7 @@ class ShadowUsersBackendTests(object):
             self.federated_user["idp_id"],
             self.federated_user["protocol_id"],
             self.federated_user["unique_id"])
-        self.assertItemsEqual(user_dict_create, user_dict_get)
+        self.assertCountEqual(user_dict_create, user_dict_get)
         self.assertEqual(user_dict_create["id"], user_dict_get["id"])
 
     def test_update_federated_user_display_name(self):
@@ -116,22 +123,46 @@ class ShadowUsersBackendTests(object):
         now = datetime.datetime.utcnow().date()
         password = uuid.uuid4().hex
         user = self._create_user(password)
-        user_auth = PROVIDERS.identity_api.authenticate(
-            self.make_request(),
-            user_id=user['id'],
-            password=password)
+        with self.make_request():
+            user_auth = PROVIDERS.identity_api.authenticate(
+                user_id=user['id'],
+                password=password)
         user_ref = self._get_user_ref(user_auth['id'])
         self.assertGreaterEqual(now, user_ref.last_active_at)
 
+    def test_set_last_active_at_on_non_existing_user(self):
+        self.config_fixture.config(group='security_compliance',
+                                   disable_user_account_days_inactive=90)
+        password = uuid.uuid4().hex
+        user = self._create_user(password)
+
+        # the user can be deleted while authentication is running; to imitate
+        # this, set_last_active_at is mocked to delete the user and then run
+        # normally
+        real_last_active_at = shadow_sql.ShadowUsers.set_last_active_at
+        test_self = self
+
+        def fake_last_active_at(self, user_id):
+            test_self._delete_user(user_id)
+            real_last_active_at(self, user_id)
+
+        with mock.patch.object(shadow_sql.ShadowUsers, 'set_last_active_at',
+                               fake_last_active_at):
+            with self.make_request():
+                # the call is expected to just succeed without exceptions
+                PROVIDERS.identity_api.authenticate(
+                    user_id=user['id'],
+                    password=password)
+
     def test_set_last_active_at_when_config_setting_is_none(self):
         self.config_fixture.config(group='security_compliance',
                                    disable_user_account_days_inactive=None)
         password = uuid.uuid4().hex
         user = self._create_user(password)
-        user_auth = PROVIDERS.identity_api.authenticate(
-            self.make_request(),
-            user_id=user['id'],
-            password=password)
+        with self.make_request():
+            user_auth = PROVIDERS.identity_api.authenticate(
+                user_id=user['id'],
+                password=password)
         user_ref = self._get_user_ref(user_auth['id'])
         self.assertIsNone(user_ref.last_active_at)
 
@@ -149,6 +180,9 @@ class ShadowUsersBackendTests(object):
         }
         return PROVIDERS.identity_api.create_user(user)
 
+    def _delete_user(self, user_id):
+        return PROVIDERS.identity_api.delete_user(user_id)
+
     def _get_user_ref(self, user_id):
         with sql.session_for_read() as session:
-            return session.query(model.User).get(user_id)
+            return session.get(model.User, user_id)
