@@ -225,7 +225,7 @@ class UserResourceOptionTests(test_backend_sql.SqlTests):
 
     def _get_user_ref(self, user_id):
         with sql.session_for_read() as session:
-            return session.query(model.User).get(user_id)
+            return session.get(model.User, user_id)
 
     def _create_user(self, user_dict):
         user_dict['id'] = uuid.uuid4().hex
@@ -342,6 +342,43 @@ class DisableInactiveUserTests(test_backend_sql.SqlTests):
         user_ref = self._get_user_ref(user['id'])
         self.assertTrue(user_ref.enabled)
 
+    def test_ignore_user_inactivity(self):
+        self.user_dict['options'] = {'ignore_user_inactivity': True}
+        user = PROVIDERS.identity_api.create_user(
+            self.user_dict)
+        # set last_active_at just beyond the max
+        last_active_at = (
+            datetime.datetime.utcnow() -
+            datetime.timedelta(self.max_inactive_days + 1)).date()
+        self._update_user_last_active_at(user['id'], last_active_at)
+        # get user and verify that the user is not disabled
+        user = PROVIDERS.identity_api.get_user(user['id'])
+        self.assertTrue(user['enabled'])
+
+    def test_ignore_user_inactivity_with_user_disabled(self):
+        user = PROVIDERS.identity_api.create_user(
+            self.user_dict)
+        # set last_active_at just beyond the max
+        last_active_at = (
+            datetime.datetime.utcnow() -
+            datetime.timedelta(self.max_inactive_days + 1)).date()
+        self._update_user_last_active_at(user['id'], last_active_at)
+        # get user and verify that the user is disabled
+        user = PROVIDERS.identity_api.get_user(user['id'])
+        self.assertFalse(user['enabled'])
+        # update disabled user with ignore_user_inactivity to true
+        user['options'] = {'ignore_user_inactivity': True}
+        user = PROVIDERS.identity_api.update_user(
+            user['id'], user)
+        # user is not enabled
+        user = PROVIDERS.identity_api.get_user(user['id'])
+        self.assertFalse(user['enabled'])
+        # Manually set enabled and test
+        user['enabled'] = True
+        PROVIDERS.identity_api.update_user(user['id'], user)
+        user = PROVIDERS.identity_api.get_user(user['id'])
+        self.assertTrue(user['enabled'])
+
     def _get_user_dict(self, password):
         user = {
             'name': uuid.uuid4().hex,
@@ -353,7 +390,7 @@ class DisableInactiveUserTests(test_backend_sql.SqlTests):
 
     def _get_user_ref(self, user_id):
         with sql.session_for_read() as session:
-            return session.query(model.User).get(user_id)
+            return session.get(model.User, user_id)
 
     def _create_user(self, user_dict, last_active_at):
         user_dict['id'] = uuid.uuid4().hex
@@ -365,7 +402,7 @@ class DisableInactiveUserTests(test_backend_sql.SqlTests):
 
     def _update_user_last_active_at(self, user_id, last_active_at):
         with sql.session_for_write() as session:
-            user_ref = session.query(model.User).get(user_id)
+            user_ref = session.get(model.User, user_id)
             user_ref.last_active_at = last_active_at
             return user_ref
 
@@ -757,7 +794,7 @@ class PasswordExpiresValidationTests(test_backend_sql.SqlTests):
         driver = PROVIDERS.identity_api.driver
         driver.create_user(user_dict['id'], user_dict)
         with sql.session_for_write() as session:
-            user_ref = session.query(model.User).get(user_dict['id'])
+            user_ref = session.get(model.User, user_dict['id'])
             user_ref.password_ref.created_at = password_created_at
             user_ref.password_ref.expires_at = (
                 user_ref._get_password_expires_at(password_created_at))
@@ -850,7 +887,7 @@ class MinimumPasswordAgeTests(test_backend_sql.SqlTests):
         # except the latest, need to have `created_at` slightly less than
         # the latest password.
         with sql.session_for_write() as session:
-            user_ref = session.query(model.User).get(user_id)
+            user_ref = session.get(model.User, user_id)
             latest_password = user_ref.password_ref
             slightly_less = datetime.timedelta(minutes=1)
             for password_ref in user_ref.local_user.passwords:
