@@ -714,6 +714,32 @@ MAPPING_EPHEMERAL_USER = {
     ]
 }
 
+MAPPING_EPHEMERAL_USER_REMOTE_DOMAIN = {
+    "rules": [
+        {
+            "local": [
+                {
+                    "user": {
+                        "name": "{0}",
+                        "domain": {
+                            "name": "{1}"
+                        },
+                        "type": "ephemeral"
+                    }
+                }
+            ],
+            "remote": [
+                {
+                    "type": "UserName"
+                },
+                {
+                    "type": "OIDC-openstack-user-domain"
+                },
+            ]
+        }
+    ]
+}
+
 MAPPING_GROUPS_WHITELIST = {
     "rules": [
         {
@@ -887,6 +913,54 @@ MAPPING_GROUPS_BLACKLIST = {
     ]
 }
 
+MAPPING_GROUPS_BLACKLIST_REGEX = {
+    "rules": [
+        {
+            "remote": [
+                {
+                    "type": "orgPersonType",
+                    "blacklist": [
+                        ".*Employee$"
+                    ],
+                    "regex": True
+                },
+            ],
+            "local": [
+                {
+                    "groups": "{0}",
+                    "domain": {
+                        "id": FEDERATED_DOMAIN
+                    }
+                },
+            ]
+        }
+    ]
+}
+
+MAPPING_GROUPS_WHITELIST_REGEX = {
+    "rules": [
+        {
+            "remote": [
+                {
+                    "type": "orgPersonType",
+                    "whitelist": [
+                        ".*Employee$"
+                    ],
+                    "regex": True
+                },
+            ],
+            "local": [
+                {
+                    "groups": "{0}",
+                    "domain": {
+                        "id": FEDERATED_DOMAIN
+                    }
+                },
+            ]
+        }
+    ]
+}
+
 # Exercise all possibilities of user identification. Values are hardcoded on
 # purpose.
 MAPPING_USER_IDS = {
@@ -1529,6 +1603,14 @@ EMPLOYEE_ASSERTION = {
     'orgPersonType': 'Employee;BuildingX'
 }
 
+EMPLOYEE_PARTTIME_ASSERTION = {
+    'Email': 'tim@example.com',
+    'UserName': 'tbo',
+    'FirstName': 'Tim',
+    'LastName': 'Bo',
+    'orgPersonType': 'Employee;PartTimeEmployee;Manager'
+}
+
 EMPLOYEE_ASSERTION_MULTIPLE_GROUPS = {
     'Email': 'tim@example.com',
     'UserName': 'tbo',
@@ -1679,6 +1761,12 @@ GROUPS_ASSERTION_ONLY_ONE_GROUP = {
     'groups': 'ALL USERS'
 }
 
+GROUPS_ASSERTION_ONLY_ONE_NUMERICAL_GROUP = {
+    'userEmail': 'jill@example.com',
+    'UserName': 'jsmith',
+    'groups': '1234'
+}
+
 GROUPS_DOMAIN_ASSERTION = {
     'openstack_user': 'bwilliams',
     'openstack_user_domain': 'default',
@@ -1687,6 +1775,11 @@ GROUPS_DOMAIN_ASSERTION = {
                         'JSON:{"name":"group2","domain":{"name":"yyy"}}'
 }
 
+USER_WITH_DOMAIN_ASSERTION = {
+    'UserName': 'marek',
+    'OIDC-openstack-user-domain': 'user_domain'
+}
+
 MAPPING_UNICODE = {
     "rules": [
         {
