@@ -12,8 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import http.client
 from oslo_serialization import jsonutils
-from six.moves import http_client
 import webtest
 
 from keystone.tests import unit
@@ -113,7 +113,7 @@ class RestfulTestCase(unit.TestCase):
 
         example::
 
-            self.assertResponseStatus(response, http_client.NO_CONTENT)
+            self.assertResponseStatus(response, http.client.NO_CONTENT)
         """
         self.assertEqual(
             expected_status, response.status_code,
@@ -125,7 +125,7 @@ class RestfulTestCase(unit.TestCase):
         self.assertIn('X-Auth-Token', response.headers.get('Vary'))
 
     def assertValidErrorResponse(self, response,
-                                 expected_status=http_client.BAD_REQUEST):
+                                 expected_status=http.client.BAD_REQUEST):
         """Verify that the error response is valid.
 
         Subclasses can override this function based on the expected response.
@@ -189,7 +189,7 @@ class RestfulTestCase(unit.TestCase):
 
         # we can save some code & improve coverage by always doing this
         if (method != 'HEAD' and
-                response.status_code >= http_client.BAD_REQUEST):
+                response.status_code >= http.client.BAD_REQUEST):
             self.assertValidErrorResponse(response)
 
         # Contains the decoded response.body
