@@ -311,8 +311,8 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         self.skip_test_overrides(BROKEN_WRITE_FUNCTIONALITY_MSG)
 
     def test_list_endpoints(self):
-        expected_urls = set(['http://localhost:$(public_port)s/v3',
-                             'http://localhost:$(admin_port)s/v3',
+        expected_urls = set(['http://localhost:5000/v3',
+                             'http://localhost:35357/v3',
                              'http://localhost:8774/v1.1/$(tenant_id)s'])
         endpoints = PROVIDERS.catalog_api.list_endpoints()
         self.assertEqual(expected_urls, set(e['url'] for e in endpoints))
