@@ -13,12 +13,13 @@
 import base64
 import datetime
 import hashlib
-import mock
 import os
+from unittest import mock
 import uuid
 
+import fixtures
+from oslo_log import log
 from oslo_utils import timeutils
-import six
 
 from keystone import auth
 from keystone.common import fernet_utils
@@ -27,6 +28,7 @@ from keystone.common import utils
 import keystone.conf
 from keystone import exception
 from keystone.federation import constants as federation_constants
+from keystone.models import token_model
 from keystone.tests import unit
 from keystone.tests.unit import default_fixtures
 from keystone.tests.unit import ksfixtures
@@ -52,6 +54,59 @@ class TestFernetTokenProvider(unit.TestCase):
             self.provider.validate_token,
             token_id)
 
+    def test_log_warning_when_token_exceeds_max_token_size_default(self):
+        self.logging = self.useFixture(fixtures.FakeLogger(level=log.INFO))
+
+        token = token_model.TokenModel()
+        token.user_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.project_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.expires_at = utils.isotime(
+            provider.default_expire_time(), subsecond=True)
+        token.methods = ['password']
+        token.audit_id = provider.random_urlsafe_str()
+        token_id, issued_at = self.provider.generate_id_and_issued_at(token)
+        expected_output = (
+            f'Fernet token created with length of {len(token_id)} characters, '
+            'which exceeds 255 characters'
+        )
+        self.assertIn(expected_output, self.logging.output)
+
+    def test_log_warning_when_token_exceeds_max_token_size_override(self):
+        self.logging = self.useFixture(fixtures.FakeLogger(level=log.INFO))
+        self.config_fixture.config(max_token_size=250)
+
+        token = token_model.TokenModel()
+        token.user_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.project_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.expires_at = utils.isotime(
+            provider.default_expire_time(), subsecond=True)
+        token.methods = ['password']
+        token.audit_id = provider.random_urlsafe_str()
+        token_id, issued_at = self.provider.generate_id_and_issued_at(token)
+        expected_output = (
+            f'Fernet token created with length of {len(token_id)} characters, '
+            'which exceeds 250 characters'
+        )
+        self.assertIn(expected_output, self.logging.output)
+
+    def test_no_warning_when_token_does_not_exceed_max_token_size(self):
+        self.config_fixture.config(max_token_size=300)
+        self.logging = self.useFixture(fixtures.FakeLogger(level=log.INFO))
+
+        token = token_model.TokenModel()
+        token.user_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.project_id = '0123456789abcdef0123456789abcdef0123456789abcdef'
+        token.expires_at = utils.isotime(
+            provider.default_expire_time(), subsecond=True)
+        token.methods = ['password']
+        token.audit_id = provider.random_urlsafe_str()
+        token_id, issued_at = self.provider.generate_id_and_issued_at(token)
+        expected_output = (
+            f'Fernet token created with length of {len(token_id)} characters, '
+            'which exceeds 255 characters'
+        )
+        self.assertNotIn(expected_output, self.logging.output)
+
 
 class TestValidate(unit.TestCase):
     def setUp(self):
@@ -227,11 +282,11 @@ class TestTokenFormatter(unit.TestCase):
         binary_to_test = [b'a', b'aa', b'aaa']
 
         for binary in binary_to_test:
-            # base64.urlsafe_b64encode takes six.binary_type and returns
-            # six.binary_type.
+            # base64.urlsafe_b64encode takes bytes and returns
+            # bytes.
             encoded_string = base64.urlsafe_b64encode(binary)
             encoded_string = encoded_string.decode('utf-8')
-            # encoded_string is now six.text_type.
+            # encoded_string is now str.
             encoded_str_without_padding = encoded_string.rstrip('=')
             self.assertFalse(encoded_str_without_padding.endswith('='))
             encoded_str_with_padding_restored = (
@@ -250,21 +305,23 @@ class TestTokenFormatter(unit.TestCase):
         exp_protocol_id = uuid.uuid4().hex
 
         token_formatter = token_formatters.TokenFormatter()
-        token = token_formatter.create_token(user_id=exp_user_id,
-                                             expires_at=exp_expires_at,
-                                             audit_ids=exp_audit_ids,
-                                             payload_class=token_formatters.FederatedUnscopedPayload,
-                                             methods=exp_methods,
-                                             federated_group_ids=exp_federated_group_ids,
-                                             identity_provider_id=exp_idp_id,
-                                             protocol_id=exp_protocol_id)
+        token = token_formatter.create_token(
+            user_id=exp_user_id,
+            expires_at=exp_expires_at,
+            audit_ids=exp_audit_ids,
+            payload_class=token_formatters.FederatedUnscopedPayload,
+            methods=exp_methods,
+            federated_group_ids=exp_federated_group_ids,
+            identity_provider_id=exp_idp_id,
+            protocol_id=exp_protocol_id)
 
         (user_id, methods, audit_ids, system, domain_id, project_id, trust_id,
          federated_group_ids, identity_provider_id, protocol_id,
-         access_token_id, app_cred_id, issued_at, expires_at) = token_formatter.validate_token(token)
+         access_token_id, app_cred_id, thumbprint, issued_at,
+         expires_at) = token_formatter.validate_token(token)
 
         self.assertEqual(exp_user_id, user_id)
-        self.assertTrue(isinstance(user_id, six.string_types))
+        self.assertTrue(isinstance(user_id, str))
         self.assertEqual(exp_methods, methods)
         self.assertEqual(exp_audit_ids, audit_ids)
         self.assertEqual(exp_federated_group_ids, federated_group_ids)
@@ -282,22 +339,24 @@ class TestTokenFormatter(unit.TestCase):
         exp_project_id = uuid.uuid4().hex
 
         token_formatter = token_formatters.TokenFormatter()
-        token = token_formatter.create_token(user_id=exp_user_id,
-                                             expires_at=exp_expires_at,
-                                             audit_ids=exp_audit_ids,
-                                             payload_class=token_formatters.FederatedProjectScopedPayload,
-                                             methods=exp_methods,
-                                             federated_group_ids=exp_federated_group_ids,
-                                             identity_provider_id=exp_idp_id,
-                                             protocol_id=exp_protocol_id,
-                                             project_id=exp_project_id)
+        token = token_formatter.create_token(
+            user_id=exp_user_id,
+            expires_at=exp_expires_at,
+            audit_ids=exp_audit_ids,
+            payload_class=token_formatters.FederatedProjectScopedPayload,
+            methods=exp_methods,
+            federated_group_ids=exp_federated_group_ids,
+            identity_provider_id=exp_idp_id,
+            protocol_id=exp_protocol_id,
+            project_id=exp_project_id)
 
         (user_id, methods, audit_ids, system, domain_id, project_id, trust_id,
          federated_group_ids, identity_provider_id, protocol_id,
-         access_token_id, app_cred_id, issued_at, expires_at) = token_formatter.validate_token(token)
+         access_token_id, app_cred_id, thumbprint, issued_at,
+         expires_at) = token_formatter.validate_token(token)
 
         self.assertEqual(exp_user_id, user_id)
-        self.assertTrue(isinstance(user_id, six.string_types))
+        self.assertTrue(isinstance(user_id, str))
         self.assertEqual(exp_methods, methods)
         self.assertEqual(exp_audit_ids, audit_ids)
         self.assertEqual(exp_project_id, project_id)
@@ -323,10 +382,10 @@ class TestPayloads(unit.TestCase):
 
     def test_strings_can_be_converted_to_bytes(self):
         s = provider.random_urlsafe_str()
-        self.assertIsInstance(s, six.text_type)
+        self.assertIsInstance(s, str)
 
         b = token_formatters.BasePayload.random_urlsafe_str_to_bytes(s)
-        self.assertIsInstance(b, six.binary_type)
+        self.assertIsInstance(b, bytes)
 
     def test_uuid_hex_to_byte_conversions(self):
         payload_cls = token_formatters.BasePayload
@@ -414,9 +473,9 @@ class TestPayloads(unit.TestCase):
                       exp_trust_id=None, exp_federated_group_ids=None,
                       exp_identity_provider_id=None, exp_protocol_id=None,
                       exp_access_token_id=None, exp_app_cred_id=None,
-                      encode_ids=False):
+                      encode_ids=False, exp_thumbprint=None):
         def _encode_id(value):
-            if value is not None and six.text_type(value) and encode_ids:
+            if value is not None and str(value) and encode_ids:
                 return value.encode('utf-8')
             return value
         exp_user_id = exp_user_id or uuid.uuid4().hex
@@ -437,12 +496,14 @@ class TestPayloads(unit.TestCase):
             _encode_id(exp_identity_provider_id),
             exp_protocol_id,
             _encode_id(exp_access_token_id),
-            _encode_id(exp_app_cred_id))
+            _encode_id(exp_app_cred_id),
+            exp_thumbprint)
 
         (user_id, methods, system, project_id,
          domain_id, expires_at, audit_ids,
          trust_id, federated_group_ids, identity_provider_id, protocol_id,
-         access_token_id, app_cred_id) = payload_class.disassemble(payload)
+         access_token_id, app_cred_id,
+         thumbprint) = payload_class.disassemble(payload)
 
         self.assertEqual(exp_user_id, user_id)
         self.assertEqual(exp_methods, methods)
@@ -622,7 +683,7 @@ class TestFernetKeyRotation(unit.TestCase):
         static set of keys, and simply shuffling them, would fail such a test).
 
         """
-        # Load the keys into a list, keys is list of six.text_type.
+        # Load the keys into a list, keys is list of str.
         key_utils = fernet_utils.FernetUtils(
             CONF.fernet_tokens.key_repository,
             CONF.fernet_tokens.max_active_keys,
@@ -637,7 +698,7 @@ class TestFernetKeyRotation(unit.TestCase):
         # Create the thumbprint using all keys in the repository.
         signature = hashlib.sha1()
         for key in keys:
-            # Need to convert key to six.binary_type for update.
+            # Need to convert key to bytes for update.
             signature.update(key.encode('utf-8'))
         return signature.hexdigest()
 
