@@ -13,7 +13,6 @@
 # under the License.
 
 from oslo_utils import timeutils
-from six.moves import range
 
 import sqlalchemy
 from sqlalchemy.ext.hybrid import hybrid_property
@@ -172,17 +171,21 @@ class Trust(base.TrustDriverBase):
                       filter_by(trustee_user_id=trustee_user_id))
             return [trust_ref.to_dict() for trust_ref in trusts]
 
-    def list_trusts_for_trustor(self, trustor_user_id):
+    def list_trusts_for_trustor(self, trustor_user_id,
+                                redelegated_trust_id=None):
         with sql.session_for_read() as session:
             trusts = (session.query(TrustModel).
                       filter_by(deleted_at=None).
                       filter_by(trustor_user_id=trustor_user_id))
+            if redelegated_trust_id:
+                trusts = trusts.filter_by(
+                    redelegated_trust_id=redelegated_trust_id)
             return [trust_ref.to_dict() for trust_ref in trusts]
 
     @sql.handle_conflicts(conflict_type='trust')
     def delete_trust(self, trust_id):
         with sql.session_for_write() as session:
-            trust_ref = session.query(TrustModel).get(trust_id)
+            trust_ref = session.get(TrustModel, trust_id)
             if not trust_ref:
                 raise exception.TrustNotFound(trust_id=trust_id)
             trust_ref.deleted_at = timeutils.utcnow()
